@@ -85,104 +85,298 @@
         <source>Clear CD-RW Disk</source>
         <translation>Slet CD-RW disk</translation>
     </message>
+    <message>
+        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre: </source>
+        <translation type="unfinished">Genre:</translation>
+    </message>
+    <message>
+        <source>Compilation Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EditMetadataDialog</name>
+    <message>
+        <source>Done</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB Statistics</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Various Artists</source>
+        <translation type="unfinished">Diverse kunstnere</translation>
+    </message>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Compilation Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to Database Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File and Database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit/Do Not Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to save the modified metadata to the file?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PlaybackBox</name>
     <message>
         <source>Edit Playlist</source>
-        <translation>Redigér musikliste</translation>
+        <translation type="obsolete">Redigér musikliste</translation>
     </message>
     <message>
         <source>Visualize</source>
-        <translation>Visualisér</translation>
+        <translation type="obsolete">Visualisér</translation>
     </message>
     <message>
         <source>3 Edit Playlist</source>
-        <translation>3 Redigér musikliste</translation>
+        <translation type="obsolete">3 Redigér musikliste</translation>
     </message>
     <message>
         <source>4 Visualize</source>
-        <translation>4 Visualisér</translation>
+        <translation type="obsolete">4 Visualisér</translation>
     </message>
     <message>
         <source>1 Shuffle: Smart</source>
-        <translation>1 Bland: Smart</translation>
+        <translation type="obsolete">1 Bland: Smart</translation>
     </message>
     <message>
         <source>Shuffle: Smart</source>
-        <translation>Bland: Smart</translation>
+        <translation type="obsolete">Bland: Smart</translation>
     </message>
     <message>
         <source>1 Shuffle: Rand</source>
-        <translation>1 Bland: Tilfældigt</translation>
+        <translation type="obsolete">1 Bland: Tilfældigt</translation>
     </message>
     <message>
         <source>Shuffle: Rand</source>
-        <translation>Bland: Tilfældigt</translation>
+        <translation type="obsolete">Bland: Tilfældigt</translation>
     </message>
     <message>
         <source>1 Shuffle: None</source>
-        <translation>1 Bland: Ingen</translation>
+        <translation type="obsolete">1 Bland: Ingen</translation>
     </message>
     <message>
         <source>Shuffle: None</source>
-        <translation>Bland: Ingen</translation>
+        <translation type="obsolete">Bland: Ingen</translation>
     </message>
     <message>
         <source>2 Repeat: All</source>
-        <translation>2 Gentag: Alle</translation>
+        <translation type="obsolete">2 Gentag: Alle</translation>
     </message>
     <message>
         <source>Repeat: All</source>
-        <translation>Gentag: Alle</translation>
+        <translation type="obsolete">Gentag: Alle</translation>
     </message>
     <message>
         <source>2 Repeat: Track</source>
-        <translation>2 Gentag: Spor</translation>
+        <translation type="obsolete">2 Gentag: Spor</translation>
     </message>
     <message>
         <source>Repeat: Track</source>
-        <translation>Gentag: Spor</translation>
+        <translation type="obsolete">Gentag: Spor</translation>
     </message>
     <message>
         <source>2 Repeat: None</source>
-        <translation>2 Gentag: Ingen</translation>
+        <translation type="obsolete">2 Gentag: Ingen</translation>
     </message>
     <message>
         <source>Repeat: None</source>
-        <translation>Gentag: Ingen</translation>
+        <translation type="obsolete">Gentag: Ingen</translation>
     </message>
     <message>
         <source>Playing stream.</source>
-        <translation>Afspiller musik.</translation>
+        <translation type="obsolete">Afspiller musik.</translation>
     </message>
     <message>
         <source>Buffering stream.</source>
-        <translation>Forbereder musik.</translation>
+        <translation type="obsolete">Forbereder musik.</translation>
     </message>
     <message>
         <source>Stream paused.</source>
-        <translation>Musik sat på pause.</translation>
+        <translation type="obsolete">Musik sat på pause.</translation>
     </message>
     <message>
         <source>Output error.</source>
-        <translation>Output-fejl.</translation>
+        <translation type="obsolete">Output-fejl.</translation>
     </message>
     <message>
         <source>Stream stopped.</source>
-        <translation>Musik stoppet.</translation>
+        <translation type="obsolete">Musik stoppet.</translation>
     </message>
     <message>
         <source>Finished playing stream.</source>
-        <translation>Musik afsluttet.</translation>
+        <translation type="obsolete">Musik afsluttet.</translation>
     </message>
     <message>
         <source>Decoder error.</source>
-        <translation>Dekoder-fejl.</translation>
+        <translation type="obsolete">Dekoder-fejl.</translation>
     </message>
     <message>
         <source>playlist root</source>
-        <translation>rod af spilleliste</translation>
+        <translation type="obsolete">rod af spilleliste</translation>
+    </message>
+    <message>
+        <source>ch</source>
+        <translation type="obsolete">kanaler</translation>
+    </message>
+</context>
+<context>
+    <name>PlaybackBoxMusic</name>
+    <message>
+        <source>Edit Playlist</source>
+        <translation type="unfinished">Redigér musikliste</translation>
+    </message>
+    <message>
+        <source>Visualize</source>
+        <translation type="unfinished">Visualisér</translation>
+    </message>
+    <message>
+        <source>3 Edit Playlist</source>
+        <translation type="unfinished">3 Redigér musikliste</translation>
+    </message>
+    <message>
+        <source>4 Visualize</source>
+        <translation type="unfinished">4 Visualisér</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Smart</source>
+        <translation type="unfinished">1 Bland: Smart</translation>
+    </message>
+    <message>
+        <source>Shuffle: Smart</source>
+        <translation type="unfinished">Bland: Smart</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Rand</source>
+        <translation type="unfinished">1 Bland: Tilfældigt</translation>
+    </message>
+    <message>
+        <source>Shuffle: Rand</source>
+        <translation type="unfinished">Bland: Tilfældigt</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: None</source>
+        <translation type="unfinished">1 Bland: Ingen</translation>
+    </message>
+    <message>
+        <source>Shuffle: None</source>
+        <translation type="unfinished">Bland: Ingen</translation>
+    </message>
+    <message>
+        <source>2 Repeat: All</source>
+        <translation type="unfinished">2 Gentag: Alle</translation>
+    </message>
+    <message>
+        <source>Repeat: All</source>
+        <translation type="unfinished">Gentag: Alle</translation>
+    </message>
+    <message>
+        <source>2 Repeat: Track</source>
+        <translation type="unfinished">2 Gentag: Spor</translation>
+    </message>
+    <message>
+        <source>Repeat: Track</source>
+        <translation type="unfinished">Gentag: Spor</translation>
+    </message>
+    <message>
+        <source>2 Repeat: None</source>
+        <translation type="unfinished">2 Gentag: Ingen</translation>
+    </message>
+    <message>
+        <source>Repeat: None</source>
+        <translation type="unfinished">Gentag: Ingen</translation>
+    </message>
+    <message>
+        <source>playlist root</source>
+        <translation type="unfinished">rod af spilleliste</translation>
+    </message>
+    <message>
+        <source>Playing stream.</source>
+        <translation type="unfinished">Afspiller musik.</translation>
+    </message>
+    <message>
+        <source>Buffering stream.</source>
+        <translation type="unfinished">Forbereder musik.</translation>
+    </message>
+    <message>
+        <source>Stream paused.</source>
+        <translation type="unfinished">Musik sat på pause.</translation>
+    </message>
+    <message>
+        <source>ch</source>
+        <translation type="unfinished">kanaler</translation>
+    </message>
+    <message>
+        <source>Output error.</source>
+        <translation type="unfinished">Output-fejl.</translation>
+    </message>
+    <message>
+        <source>Stream stopped.</source>
+        <translation type="unfinished">Musik stoppet.</translation>
+    </message>
+    <message>
+        <source>Finished playing stream.</source>
+        <translation type="unfinished">Musik afsluttet.</translation>
+    </message>
+    <message>
+        <source>Decoder error.</source>
+        <translation type="unfinished">Dekoder-fejl.</translation>
     </message>
     <message>
         <source>kbps</source>
@@ -193,8 +387,28 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>ch</source>
-        <translation>kanaler</translation>
+        <source>Smart playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks by current Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Year</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -249,7 +463,7 @@
     </message>
     <message>
         <source>CDRom device used for ripping/playback.</source>
-        <translation>CDROM-enhed der anvendes til kopiering (rip) og afspilning af CD'er.</translation>
+        <translation>CDROM-enhed der anvendes til kopiering (rip) og afspilning af CD&apos;er.</translation>
     </message>
     <message>
         <source>Tree Sorting</source>
@@ -285,7 +499,7 @@
     </message>
     <message>
         <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
-        <translation>Hvis dette felt er markeret, vil MythMusic automatisk hente information om CD'er i drevet og vise denne.</translation>
+        <translation>Hvis dette felt er markeret, vil MythMusic automatisk hente information om CD&apos;er i drevet og vise denne.</translation>
     </message>
     <message>
         <source>Use Keyboard/Remote Accelerated Buttons</source>
@@ -309,7 +523,7 @@
     </message>
     <message>
         <source>Audio encoder to use for CD ripping. Note that the quality level &apos;Perfect&apos; will use the FLAC encoder.</source>
-        <translation>Formatet der anvendes ved kopiering (rip) af CD'er. Bemærk, at kvalitetsniveauet &apos;Perfekt&apos; vil resultere i anvendelsen af FLAC-formatet.</translation>
+        <translation>Formatet der anvendes ved kopiering (rip) af CD&apos;er. Bemærk, at kvalitetsniveauet &apos;Perfekt&apos; vil resultere i anvendelsen af FLAC-formatet.</translation>
     </message>
     <message>
         <source>File storage location</source>
@@ -353,7 +567,7 @@
     </message>
     <message>
         <source>Paranoia level of the CD ripper. Set to faster if you&apos;re not concerned about possible errors in the audio.</source>
-        <translation>Fastsætter trade-off imellem hastighed og antal fejl ved kopiering (rip) af CD'er. Sæt dette til &apos;hurtigt&apos; hvis du er ligeglad med eventuelle fejl i de færdige lyd-filer.</translation>
+        <translation>Fastsætter trade-off imellem hastighed og antal fejl ved kopiering (rip) af CD&apos;er. Sæt dette til &apos;hurtigt&apos; hvis du er ligeglad med eventuelle fejl i de færdige lyd-filer.</translation>
     </message>
     <message>
         <source>Automatically eject CDs after ripping</source>
@@ -649,7 +863,7 @@
     </message>
     <message>
         <source>Enable CD Writing.</source>
-        <translation>Anvend skrivning af CD'er</translation>
+        <translation>Anvend skrivning af CD&apos;er</translation>
     </message>
     <message>
         <source>Requires a SCSI or an IDE-SCSI CD Writer.</source>
@@ -755,6 +969,10 @@
         <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
         <translation>Orden for musik-hierarkiet. Mulige værdier er en liste (adskilt af mellemrum) med følgende mulige værdier: genre, splitartist, artist, album, og title ELLER &quot;directory&quot; for at indikere at billedet på skærmen har samme struktur som filsystemet.</translation>
     </message>
+    <message>
+        <source>CD: %1 ~ %2 - %3</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Ripper</name>
@@ -810,6 +1028,277 @@
         <source>Ripping...</source>
         <translation>Kopierer...</translation>
     </message>
+    <message>
+        <source>Multi-Artist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch Titles &amp;&amp; Artists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLCriteriaRow</name>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLOrderByDialog</name>
+    <message>
+        <source>Order By Fields</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5 Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6 Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7 OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLResultViewer</name>
+    <message>
+        <source>Smart Playlist Result Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistDialog</name>
+    <message>
+        <source>Smart Playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this SmartPlaylist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistEditor</name>
+    <message>
+        <source>Smart Playlist Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Category:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Any</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Of The Following Conditions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Order By:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matches:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Limit:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Smart Playlist Categories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this Category?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It will also delete any Smart Playlists belonging to this category.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -817,5 +1306,53 @@
         <source>Please Wait...</source>
         <translation>Vent venligst...</translation>
     </message>
+    <message>
+        <source>Track Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rating:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play Count:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Play:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compilation:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filename:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
