@@ -124,6 +124,93 @@
         <source>Clear CD-RW Disk</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre: </source>
+        <translation type="unfinished">Género:</translation>
+    </message>
+    <message>
+        <source>Compilation Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EditMetadataDialog</name>
+    <message>
+        <source>Done</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB Statistics</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Various Artists</source>
+        <translation type="unfinished">Varios artistas</translation>
+    </message>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Compilation Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to Database Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File and Database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit/Do Not Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to save the modified metadata to the file?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PlaybackBox</name>
@@ -137,11 +224,11 @@
     </message>
     <message>
         <source>Edit Playlist</source>
-        <translation>Editar Lista</translation>
+        <translation type="obsolete">Editar Lista</translation>
     </message>
     <message>
         <source>Visualize</source>
-        <translation>Visualizar</translation>
+        <translation type="obsolete">Visualizar</translation>
     </message>
     <message>
         <source>Rating</source>
@@ -161,39 +248,39 @@
     </message>
     <message>
         <source>Repeat: Track</source>
-        <translation>Repetir: Pista</translation>
+        <translation type="obsolete">Repetir: Pista</translation>
     </message>
     <message>
         <source>Repeat: All</source>
-        <translation>Repetir: Todo</translation>
+        <translation type="obsolete">Repetir: Todo</translation>
     </message>
     <message>
         <source>Playing stream.</source>
-        <translation>Reproduciendo.</translation>
+        <translation type="obsolete">Reproduciendo.</translation>
     </message>
     <message>
         <source>Buffering stream.</source>
-        <translation>Cargando reproducción.</translation>
+        <translation type="obsolete">Cargando reproducción.</translation>
     </message>
     <message>
         <source>Stream paused.</source>
-        <translation>Reproducción en pausa.</translation>
+        <translation type="obsolete">Reproducción en pausa.</translation>
     </message>
     <message>
         <source>Output error.</source>
-        <translation>Error de salida.</translation>
+        <translation type="obsolete">Error de salida.</translation>
     </message>
     <message>
         <source>Stream stopped.</source>
-        <translation>Reproducción parada.</translation>
+        <translation type="obsolete">Reproducción parada.</translation>
     </message>
     <message>
         <source>Finished playing stream.</source>
-        <translation>Reproducción finalizada.</translation>
+        <translation type="obsolete">Reproducción finalizada.</translation>
     </message>
     <message>
         <source>Decoder error.</source>
-        <translation>Error de decodificación.</translation>
+        <translation type="obsolete">Error de decodificación.</translation>
     </message>
     <message>
         <source>Shuffle: Intelligent</source>
@@ -213,67 +300,190 @@
     </message>
     <message>
         <source>1 Shuffle: None</source>
-        <translation>1 Aleatorio: No</translation>
+        <translation type="obsolete">1 Aleatorio: No</translation>
     </message>
     <message>
         <source>Shuffle: None</source>
-        <translation>Aleatorio: No</translation>
+        <translation type="obsolete">Aleatorio: No</translation>
     </message>
     <message>
         <source>2 Repeat: All</source>
-        <translation>2 Repetir: Todo</translation>
+        <translation type="obsolete">2 Repetir: Todo</translation>
     </message>
     <message>
         <source>2 Repeat: Track</source>
-        <translation>2 Repetir: Pista</translation>
+        <translation type="obsolete">2 Repetir: Pista</translation>
     </message>
     <message>
         <source>2 Repeat: None</source>
-        <translation>2 Repetir: No</translation>
+        <translation type="obsolete">2 Repetir: No</translation>
     </message>
     <message>
         <source>Repeat: None</source>
-        <translation>Repetir: No</translation>
+        <translation type="obsolete">Repetir: No</translation>
     </message>
     <message>
         <source>3 Edit Playlist</source>
-        <translation>3 Editar Lista</translation>
+        <translation type="obsolete">3 Editar Lista</translation>
     </message>
     <message>
         <source>4 Visualize</source>
-        <translation>4 Visualizar</translation>
+        <translation type="obsolete">4 Visualizar</translation>
     </message>
     <message>
         <source>1 Shuffle: Smart</source>
-        <translation>1 Aleatorio: Preferido</translation>
+        <translation type="obsolete">1 Aleatorio: Preferido</translation>
     </message>
     <message>
         <source>Shuffle: Smart</source>
-        <translation>Aleatorio: Preferido</translation>
+        <translation type="obsolete">Aleatorio: Preferido</translation>
     </message>
     <message>
         <source>1 Shuffle: Rand</source>
-        <translation>1 Aleatorio: Variable</translation>
+        <translation type="obsolete">1 Aleatorio: Variable</translation>
     </message>
     <message>
         <source>Shuffle: Rand</source>
-        <translation>Aleatorio: Variable</translation>
+        <translation type="obsolete">Aleatorio: Variable</translation>
     </message>
     <message>
         <source>playlist root</source>
-        <translation>raiz de la lista</translation>
+        <translation type="obsolete">raiz de la lista</translation>
+    </message>
+</context>
+<context>
+    <name>PlaybackBoxMusic</name>
+    <message>
+        <source>Edit Playlist</source>
+        <translation type="unfinished">Editar Lista</translation>
+    </message>
+    <message>
+        <source>Visualize</source>
+        <translation type="unfinished">Visualizar</translation>
+    </message>
+    <message>
+        <source>3 Edit Playlist</source>
+        <translation type="unfinished">3 Editar Lista</translation>
+    </message>
+    <message>
+        <source>4 Visualize</source>
+        <translation type="unfinished">4 Visualizar</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Smart</source>
+        <translation type="unfinished">1 Aleatorio: Preferido</translation>
+    </message>
+    <message>
+        <source>Shuffle: Smart</source>
+        <translation type="unfinished">Aleatorio: Preferido</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Rand</source>
+        <translation type="unfinished">1 Aleatorio: Variable</translation>
+    </message>
+    <message>
+        <source>Shuffle: Rand</source>
+        <translation type="unfinished">Aleatorio: Variable</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: None</source>
+        <translation type="unfinished">1 Aleatorio: No</translation>
+    </message>
+    <message>
+        <source>Shuffle: None</source>
+        <translation type="unfinished">Aleatorio: No</translation>
+    </message>
+    <message>
+        <source>2 Repeat: All</source>
+        <translation type="unfinished">2 Repetir: Todo</translation>
+    </message>
+    <message>
+        <source>Repeat: All</source>
+        <translation type="unfinished">Repetir: Todo</translation>
+    </message>
+    <message>
+        <source>2 Repeat: Track</source>
+        <translation type="unfinished">2 Repetir: Pista</translation>
+    </message>
+    <message>
+        <source>Repeat: Track</source>
+        <translation type="unfinished">Repetir: Pista</translation>
+    </message>
+    <message>
+        <source>2 Repeat: None</source>
+        <translation type="unfinished">2 Repetir: No</translation>
+    </message>
+    <message>
+        <source>Repeat: None</source>
+        <translation type="unfinished">Repetir: No</translation>
+    </message>
+    <message>
+        <source>playlist root</source>
+        <translation type="unfinished">raiz de la lista</translation>
+    </message>
+    <message>
+        <source>Playing stream.</source>
+        <translation type="unfinished">Reproduciendo.</translation>
+    </message>
+    <message>
+        <source>Buffering stream.</source>
+        <translation type="unfinished">Cargando reproducción.</translation>
+    </message>
+    <message>
+        <source>Stream paused.</source>
+        <translation type="unfinished">Reproducción en pausa.</translation>
+    </message>
+    <message>
+        <source>Output error.</source>
+        <translation type="unfinished">Error de salida.</translation>
+    </message>
+    <message>
+        <source>Stream stopped.</source>
+        <translation type="unfinished">Reproducción parada.</translation>
+    </message>
+    <message>
+        <source>Finished playing stream.</source>
+        <translation type="unfinished">Reproducción finalizada.</translation>
+    </message>
+    <message>
+        <source>Decoder error.</source>
+        <translation type="unfinished">Error de decodificación.</translation>
     </message>
     <message>
         <source>kbps</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>kHz</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>ch</source>
-        <translation></translation>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Smart playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks by current Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Year</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -856,6 +1066,10 @@ You have no MythMusic tables in your database.</source>
         <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>CD: %1 ~ %2 - %3</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Ripper</name>
@@ -911,6 +1125,277 @@ You have no MythMusic tables in your database.</source>
         <source>Ripping...</source>
         <translation>Ripeando...</translation>
     </message>
+    <message>
+        <source>Multi-Artist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch Titles &amp;&amp; Artists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished">Duración</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLCriteriaRow</name>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLOrderByDialog</name>
+    <message>
+        <source>Order By Fields</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5 Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6 Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7 OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLResultViewer</name>
+    <message>
+        <source>Smart Playlist Result Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished">Artista</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Título</translation>
+    </message>
+    <message>
+        <source>Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistDialog</name>
+    <message>
+        <source>Smart Playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this SmartPlaylist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistEditor</name>
+    <message>
+        <source>Smart Playlist Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Category:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Any</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Of The Following Conditions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Order By:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matches:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Limit:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Smart Playlist Categories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this Category?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It will also delete any Smart Playlists belonging to this category.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -918,5 +1403,53 @@ You have no MythMusic tables in your database.</source>
         <source>Please Wait...</source>
         <translation>Aguarde un momento...</translation>
     </message>
+    <message>
+        <source>Track Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rating:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play Count:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Play:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compilation:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filename:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
