@@ -85,116 +85,338 @@
         <source>Clear CD-RW Disk</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre: </source>
+        <translation type="unfinished">Genere:</translation>
+    </message>
+    <message>
+        <source>Compilation Artist:<byte value="x9"/></source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>EditMetadataDialog</name>
+    <message>
+        <source>Done</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>DB Statistics</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Various Artists</source>
+        <translation type="unfinished">Artisti Vari</translation>
+    </message>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Compilation Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save Changes?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to Database Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save to File and Database</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit/Do Not Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to save the modified metadata to the file?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PlaybackBox</name>
     <message>
         <source>Edit Playlist</source>
-        <translation>Modifica la Playlist</translation>
+        <translation type="obsolete">Modifica la Playlist</translation>
     </message>
     <message>
         <source>Visualize</source>
-        <translation>Visualizza</translation>
+        <translation type="obsolete">Visualizza</translation>
     </message>
     <message>
         <source>Repeat: Track</source>
-        <translation>Ripetizione: Traccia</translation>
+        <translation type="obsolete">Ripetizione: Traccia</translation>
     </message>
     <message>
         <source>Repeat: All</source>
-        <translation>Ripetizione: Tutto</translation>
+        <translation type="obsolete">Ripetizione: Tutto</translation>
     </message>
     <message>
         <source>Playing stream.</source>
-        <translation>Esecuzione brano.</translation>
+        <translation type="obsolete">Esecuzione brano.</translation>
     </message>
     <message>
         <source>Buffering stream.</source>
-        <translation>Buffering del brano.</translation>
+        <translation type="obsolete">Buffering del brano.</translation>
     </message>
     <message>
         <source>Stream paused.</source>
-        <translation>Brano in pausa.</translation>
+        <translation type="obsolete">Brano in pausa.</translation>
     </message>
     <message>
         <source>Output error.</source>
-        <translation>Errore di Output.</translation>
+        <translation type="obsolete">Errore di Output.</translation>
     </message>
     <message>
         <source>Stream stopped.</source>
-        <translation>Brano fermato.</translation>
+        <translation type="obsolete">Brano fermato.</translation>
     </message>
     <message>
         <source>Finished playing stream.</source>
-        <translation>Esecuzione terminata.</translation>
+        <translation type="obsolete">Esecuzione terminata.</translation>
     </message>
     <message>
         <source>Decoder error.</source>
-        <translation>Errore di decodifica.</translation>
+        <translation type="obsolete">Errore di decodifica.</translation>
     </message>
     <message>
         <source>1 Shuffle: None</source>
-        <translation>1 Ordine: No</translation>
+        <translation type="obsolete">1 Ordine: No</translation>
     </message>
     <message>
         <source>Shuffle: None</source>
-        <translation>Ordine: No</translation>
+        <translation type="obsolete">Ordine: No</translation>
     </message>
     <message>
         <source>2 Repeat: All</source>
-        <translation>2 Ripeti: Tutti</translation>
+        <translation type="obsolete">2 Ripeti: Tutti</translation>
     </message>
     <message>
         <source>2 Repeat: Track</source>
-        <translation>2 Ripeti: Traccia</translation>
+        <translation type="obsolete">2 Ripeti: Traccia</translation>
     </message>
     <message>
         <source>2 Repeat: None</source>
-        <translation>2 Ripeti: No</translation>
+        <translation type="obsolete">2 Ripeti: No</translation>
     </message>
     <message>
         <source>Repeat: None</source>
-        <translation>Ripeti: No</translation>
+        <translation type="obsolete">Ripeti: No</translation>
     </message>
     <message>
         <source>3 Edit Playlist</source>
-        <translation>3 Modifica Playlist</translation>
+        <translation type="obsolete">3 Modifica Playlist</translation>
     </message>
     <message>
         <source>4 Visualize</source>
-        <translation>4 Visualizza</translation>
+        <translation type="obsolete">4 Visualizza</translation>
     </message>
     <message>
         <source>1 Shuffle: Smart</source>
-        <translation>1 Ordine: Furbo</translation>
+        <translation type="obsolete">1 Ordine: Furbo</translation>
     </message>
     <message>
         <source>Shuffle: Smart</source>
-        <translation>Ordine: Furbo</translation>
+        <translation type="obsolete">Ordine: Furbo</translation>
     </message>
     <message>
         <source>1 Shuffle: Rand</source>
-        <translation>1 Ordine: Casuale</translation>
+        <translation type="obsolete">1 Ordine: Casuale</translation>
     </message>
     <message>
         <source>Shuffle: Rand</source>
-        <translation>Ordine: Casuale</translation>
+        <translation type="obsolete">Ordine: Casuale</translation>
     </message>
     <message>
         <source>playlist root</source>
-        <translation>Radice della Playlist</translation>
+        <translation type="obsolete">Radice della Playlist</translation>
     </message>
     <message>
         <source>kbps</source>
-        <translation>kbps</translation>
+        <translation type="obsolete">kbps</translation>
     </message>
     <message>
         <source>kHz</source>
-        <translation>kHz</translation>
+        <translation type="obsolete">kHz</translation>
     </message>
     <message>
         <source>ch</source>
-        <translation>ch</translation>
+        <translation type="obsolete">ch</translation>
+    </message>
+</context>
+<context>
+    <name>PlaybackBoxMusic</name>
+    <message>
+        <source>Edit Playlist</source>
+        <translation type="unfinished">Modifica la Playlist</translation>
+    </message>
+    <message>
+        <source>Visualize</source>
+        <translation type="unfinished">Visualizza</translation>
+    </message>
+    <message>
+        <source>3 Edit Playlist</source>
+        <translation type="unfinished">3 Modifica Playlist</translation>
+    </message>
+    <message>
+        <source>4 Visualize</source>
+        <translation type="unfinished">4 Visualizza</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Smart</source>
+        <translation type="unfinished">1 Ordine: Furbo</translation>
+    </message>
+    <message>
+        <source>Shuffle: Smart</source>
+        <translation type="unfinished">Ordine: Furbo</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Rand</source>
+        <translation type="unfinished">1 Ordine: Casuale</translation>
+    </message>
+    <message>
+        <source>Shuffle: Rand</source>
+        <translation type="unfinished">Ordine: Casuale</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: None</source>
+        <translation type="unfinished">1 Ordine: No</translation>
+    </message>
+    <message>
+        <source>Shuffle: None</source>
+        <translation type="unfinished">Ordine: No</translation>
+    </message>
+    <message>
+        <source>2 Repeat: All</source>
+        <translation type="unfinished">2 Ripeti: Tutti</translation>
+    </message>
+    <message>
+        <source>Repeat: All</source>
+        <translation type="unfinished">Ripetizione: Tutto</translation>
+    </message>
+    <message>
+        <source>2 Repeat: Track</source>
+        <translation type="unfinished">2 Ripeti: Traccia</translation>
+    </message>
+    <message>
+        <source>Repeat: Track</source>
+        <translation type="unfinished">Ripetizione: Traccia</translation>
+    </message>
+    <message>
+        <source>2 Repeat: None</source>
+        <translation type="unfinished">2 Ripeti: No</translation>
+    </message>
+    <message>
+        <source>Repeat: None</source>
+        <translation type="unfinished">Ripeti: No</translation>
+    </message>
+    <message>
+        <source>playlist root</source>
+        <translation type="unfinished">Radice della Playlist</translation>
+    </message>
+    <message>
+        <source>Playing stream.</source>
+        <translation type="unfinished">Esecuzione brano.</translation>
+    </message>
+    <message>
+        <source>Buffering stream.</source>
+        <translation type="unfinished">Buffering del brano.</translation>
+    </message>
+    <message>
+        <source>Stream paused.</source>
+        <translation type="unfinished">Brano in pausa.</translation>
+    </message>
+    <message>
+        <source>kbps</source>
+        <translation type="unfinished">kbps</translation>
+    </message>
+    <message>
+        <source>kHz</source>
+        <translation type="unfinished">kHz</translation>
+    </message>
+    <message>
+        <source>ch</source>
+        <translation type="unfinished">ch</translation>
+    </message>
+    <message>
+        <source>Output error.</source>
+        <translation type="unfinished">Errore di Output.</translation>
+    </message>
+    <message>
+        <source>Stream stopped.</source>
+        <translation type="unfinished">Brano fermato.</translation>
+    </message>
+    <message>
+        <source>Finished playing stream.</source>
+        <translation type="unfinished">Esecuzione terminata.</translation>
+    </message>
+    <message>
+        <source>Decoder error.</source>
+        <translation type="unfinished">Errore di decodifica.</translation>
+    </message>
+    <message>
+        <source>Smart playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Tracks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks by current Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Tracks from current Year</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -755,6 +977,10 @@
         <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>CD: %1 ~ %2 - %3</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Ripper</name>
@@ -810,6 +1036,277 @@
         <source>Ripping...</source>
         <translation>Ripping...</translation>
     </message>
+    <message>
+        <source>Multi-Artist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Switch Titles &amp;&amp; Artists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLCriteriaRow</name>
+    <message>
+        <source>Select an Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select a Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLOrderByDialog</name>
+    <message>
+        <source>Order By Fields</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>5 Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ascending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>6 Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Descending</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>7 OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLResultViewer</name>
+    <message>
+        <source>Smart Playlist Result Viewer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ID</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistDialog</name>
+    <message>
+        <source>Smart Playlists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>1 Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>2 New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>3 Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4 Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this SmartPlaylist?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistEditor</name>
+    <message>
+        <source>Smart Playlist Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Category:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Match</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Any</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Of The Following Conditions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Order By:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Matches:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Limit:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Results</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Smart Playlist Categories</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>New Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delete Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rename Category</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this Category?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It will also delete any Smart Playlists belonging to this category.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -817,5 +1314,53 @@
         <source>Please Wait...</source>
         <translation>Attendere Prego...</translation>
     </message>
+    <message>
+        <source>Track Information</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Artist:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Album:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Track No.:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rating:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Play Count:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Last Play:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compilation:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filename:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
