@@ -82,7 +82,7 @@
     </message>
     <message>
         <source>Blechy Blech Blah</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>All My Music ~ Loading Music Data </source>
@@ -94,7 +94,7 @@
     </message>
     <message>
         <source>The theme you are using does not contain a &apos;musictree&apos; element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
-        <translation type="unfinished"></translation>
+        <translation>あなたの使用しているテーマに&apos;musictree&apos;エレメントがありません。テーマの作者に連絡してください。&lt;br&gt;&lt;br&gt;次の画面は空になるのでメインメニューに戻ります。</translation>
     </message>
     <message>
         <source>OK</source>
@@ -124,6 +124,93 @@
         <source>Clear CD-RW Disk</source>
         <translation>CD-RWディスクを消去する</translation>
     </message>
+    <message>
+        <source>The theme you are using does not contain any info lines in the music element.  Please contact the theme creator and ask if they could please update it.&lt;br&gt;&lt;br&gt;The next screen will be empty.  Escape out of it to return to the menu.</source>
+        <translation>あなたの使用しているテーマに情報ラインがありません。テーマの作者に連絡してください。&lt;br&gt;&lt;br&gt;次の画面は空になるのでメインメニューに戻ります。</translation>
+    </message>
+    <message>
+        <source>Artist:<byte value="x9"/></source>
+        <translation>アーチスト: </translation>
+    </message>
+    <message>
+        <source>Album:<byte value="x9"/></source>
+        <translation>アルバム:</translation>
+    </message>
+    <message>
+        <source>Title:<byte value="x9"/></source>
+        <translation>タイトル:</translation>
+    </message>
+    <message>
+        <source>Length:<byte value="x9"/></source>
+        <translation type="unfinished">時間:</translation>
+    </message>
+    <message>
+        <source>Genre: </source>
+        <translation>ジャンル:</translation>
+    </message>
+    <message>
+        <source>Compilation Artist:<byte value="x9"/></source>
+        <translation>編集アーチスト:</translation>
+    </message>
+</context>
+<context>
+    <name>EditMetadataDialog</name>
+    <message>
+        <source>Done</source>
+        <translation>終了</translation>
+    </message>
+    <message>
+        <source>DB Statistics</source>
+        <translation>DB統計</translation>
+    </message>
+    <message>
+        <source>Various Artists</source>
+        <translation>様々なアーティスト</translation>
+    </message>
+    <message>
+        <source>Select an Artist</source>
+        <translation>アーチストを選択</translation>
+    </message>
+    <message>
+        <source>Select a Compilation Artist</source>
+        <translation>編集アーチストを選択</translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation>アルバムを選択</translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation>ジャンルを選択</translation>
+    </message>
+    <message>
+        <source>Save Changes?</source>
+        <translation>変更を保存しますか?</translation>
+    </message>
+    <message>
+        <source>Save to Database Only</source>
+        <translation>データベースのみ保存</translation>
+    </message>
+    <message>
+        <source>Save to File Only</source>
+        <translation>ファイルにのみ保存</translation>
+    </message>
+    <message>
+        <source>Save to File and Database</source>
+        <translation>ファイルとデータベースに保存</translation>
+    </message>
+    <message>
+        <source>Exit/Do Not Save</source>
+        <translation>保存しないで終了</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>キャンセル</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to save the modified metadata to the file?</source>
+        <translation>変更をファイルに保存してよろしいですか?</translation>
+    </message>
 </context>
 <context>
     <name>PlaybackBox</name>
@@ -137,11 +224,11 @@
     </message>
     <message>
         <source>Edit Playlist</source>
-        <translation>プレイリスト編集</translation>
+        <translation type="obsolete">プレイリスト編集</translation>
     </message>
     <message>
         <source>Visualize</source>
-        <translation>ビジュアライズ</translation>
+        <translation type="obsolete">ビジュアライズ</translation>
     </message>
     <message>
         <source>Rating</source>
@@ -161,39 +248,39 @@
     </message>
     <message>
         <source>Repeat: Track</source>
-        <translation>リピート: トラック</translation>
+        <translation type="obsolete">リピート: トラック</translation>
     </message>
     <message>
         <source>Repeat: All</source>
-        <translation>リピート: 全て</translation>
+        <translation type="obsolete">リピート: 全て</translation>
     </message>
     <message>
         <source>Playing stream.</source>
-        <translation>再生ストリーム.</translation>
+        <translation type="obsolete">再生ストリーム.</translation>
     </message>
     <message>
         <source>Buffering stream.</source>
-        <translation>バッファーストリーム.</translation>
+        <translation type="obsolete">バッファーストリーム.</translation>
     </message>
     <message>
         <source>Stream paused.</source>
-        <translation>ストリーム停止中.</translation>
+        <translation type="obsolete">ストリーム停止中.</translation>
     </message>
     <message>
         <source>Output error.</source>
-        <translation>出力エラー.</translation>
+        <translation type="obsolete">出力エラー.</translation>
     </message>
     <message>
         <source>Stream stopped.</source>
-        <translation>ストリーム停止中.</translation>
+        <translation type="obsolete">ストリーム停止中.</translation>
     </message>
     <message>
         <source>Finished playing stream.</source>
-        <translation>再生ストリーム終了.</translation>
+        <translation type="obsolete">再生ストリーム終了.</translation>
     </message>
     <message>
         <source>Decoder error.</source>
-        <translation>出コードエラー.</translation>
+        <translation type="obsolete">デコードエラー.</translation>
     </message>
     <message>
         <source>Shuffle: Intelligent</source>
@@ -205,27 +292,66 @@
     </message>
     <message>
         <source>1 Shuffle: None</source>
-        <translation>1 シャッフル: 無し</translation>
+        <translation type="obsolete">1 シャッフル: 無し</translation>
     </message>
     <message>
         <source>Shuffle: None</source>
-        <translation>シャッフル: 無し</translation>
+        <translation type="obsolete">シャッフル: 無し</translation>
     </message>
     <message>
         <source>2 Repeat: All</source>
-        <translation>2 リピート: 全て</translation>
+        <translation type="obsolete">2 リピート: 全て</translation>
     </message>
     <message>
         <source>2 Repeat: Track</source>
-        <translation>2 リピート: トラック</translation>
+        <translation type="obsolete">2 リピート: トラック</translation>
     </message>
     <message>
         <source>2 Repeat: None</source>
-        <translation>2 リピート: 無し</translation>
+        <translation type="obsolete">2 リピート: 無し</translation>
     </message>
     <message>
         <source>Repeat: None</source>
-        <translation>リピート: 無し</translation>
+        <translation type="obsolete">リピート: 無し</translation>
+    </message>
+    <message>
+        <source>3 Edit Playlist</source>
+        <translation type="obsolete">3 プレイリスト編集</translation>
+    </message>
+    <message>
+        <source>4 Visualize</source>
+        <translation type="obsolete">4 ビジュアライズ</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Smart</source>
+        <translation type="obsolete">1 シャッフル: スマート</translation>
+    </message>
+    <message>
+        <source>Shuffle: Smart</source>
+        <translation type="obsolete">シャッフル: スマート</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Rand</source>
+        <translation type="obsolete">1 シャッフル: ランダム</translation>
+    </message>
+    <message>
+        <source>Shuffle: Rand</source>
+        <translation type="obsolete">シャッフル: ランダム</translation>
+    </message>
+    <message>
+        <source>playlist root</source>
+        <translation type="obsolete">プレイリストルート</translation>
+    </message>
+</context>
+<context>
+    <name>PlaybackBoxMusic</name>
+    <message>
+        <source>Edit Playlist</source>
+        <translation>プレイリスト編集</translation>
+    </message>
+    <message>
+        <source>Visualize</source>
+        <translation>ビジュアライズ</translation>
     </message>
     <message>
         <source>3 Edit Playlist</source>
@@ -251,10 +377,62 @@
         <source>Shuffle: Rand</source>
         <translation>シャッフル: ランダム</translation>
     </message>
+    <message>
+        <source>1 Shuffle: None</source>
+        <translation>1 シャッフル: 無し</translation>
+    </message>
+    <message>
+        <source>Shuffle: None</source>
+        <translation>シャッフル: 無し</translation>
+    </message>
+    <message>
+        <source>2 Repeat: All</source>
+        <translation>2 リピート: 全て</translation>
+    </message>
+    <message>
+        <source>Repeat: All</source>
+        <translation>リピート: 全て</translation>
+    </message>
+    <message>
+        <source>2 Repeat: Track</source>
+        <translation>2 リピート: トラック</translation>
+    </message>
+    <message>
+        <source>Repeat: Track</source>
+        <translation>リピート: トラック</translation>
+    </message>
+    <message>
+        <source>2 Repeat: None</source>
+        <translation>2 リピート: 無し</translation>
+    </message>
+    <message>
+        <source>Repeat: None</source>
+        <translation>リピート: 無し</translation>
+    </message>
     <message>
         <source>playlist root</source>
         <translation>プレイリストルート</translation>
     </message>
+    <message>
+        <source>Playing stream.</source>
+        <translation>再生ストリーム.</translation>
+    </message>
+    <message>
+        <source>Buffering stream.</source>
+        <translation>バッファーストリーム.</translation>
+    </message>
+    <message>
+        <source>Output error.</source>
+        <translation>出力エラー.</translation>
+    </message>
+    <message>
+        <source>Finished playing stream.</source>
+        <translation>再生ストリーム終了.</translation>
+    </message>
+    <message>
+        <source>Stream paused.</source>
+        <translation>ストリーム一時停止中.</translation>
+    </message>
     <message>
         <source>kbps</source>
         <translation></translation>
@@ -267,6 +445,38 @@
         <source>ch</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Stream stopped.</source>
+        <translation>ストリーム停止中.</translation>
+    </message>
+    <message>
+        <source>Decoder error.</source>
+        <translation>デコーダーエラー.</translation>
+    </message>
+    <message>
+        <source>Smart playlists</source>
+        <translation>スマートプレイリスト</translation>
+    </message>
+    <message>
+        <source>All Tracks</source>
+        <translation>全てのトラック</translation>
+    </message>
+    <message>
+        <source>Tracks by current Artist</source>
+        <translation>このアーチストのトラック</translation>
+    </message>
+    <message>
+        <source>Tracks from current Album</source>
+        <translation>このアルバムのトラック</translation>
+    </message>
+    <message>
+        <source>Tracks from current Genre</source>
+        <translation>このジャンルのトラック</translation>
+    </message>
+    <message>
+        <source>Tracks from current Year</source>
+        <translation>この年のトラック</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -352,7 +562,7 @@
     </message>
     <message>
         <source>If set, MythMusic will skip checking ID3 tags in files and just try to determine Genre, Artist, Album, and Track number and title from the filename.</source>
-        <translation type="unfinished"></translation>
+        <translation>これをセットするとMythMusicはファイルのID3タグを無視してファイル名からジャンル、アーチスト、アルバム、トラックナンバーとタイトルを取得します。</translation>
     </message>
     <message>
         <source>Automatically lookup CDs</source>
@@ -360,7 +570,7 @@
     </message>
     <message>
         <source>Automatically lookup an audio CD if it is present and show its information in the Music Selection Tree.</source>
-        <translation type="unfinished"></translation>
+        <translation>ミュージック選択画面で音楽CDの内容を自動的に表示します。</translation>
     </message>
     <message>
         <source>Use Keyboard/Remote Accelerated Buttons</source>
@@ -368,7 +578,7 @@
     </message>
     <message>
         <source>If this is not set, you will need to use arrow keys to select and activate various functions.</source>
-        <translation type="unfinished"></translation>
+        <translation>これをセットしないと、矢印キーで機能を選択しなければなりません。</translation>
     </message>
     <message>
         <source>Encoding</source>
@@ -392,7 +602,7 @@
     </message>
     <message>
         <source>Defines the location/name for new songs. Valid tokens are: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / and -. &apos;-&apos; will be replaced by the Token separator</source>
-        <translation type="unfinished"></translation>
+        <translation>既定の音楽の場所。使用できるパラメータは: GENRE, ARTIST, ALBUM, TRACK, TITLE, YEAR, / と - です。&apos;-&apos;はセパレーターに置き換えられます。</translation>
     </message>
     <message>
         <source>Token separator</source>
@@ -452,7 +662,7 @@
     </message>
     <message>
         <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how many times a given track has been played when ordering a group of songs.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;スマート&quot;シャッフルモードで使用されます。再生回数が曲順に影響します。</translation>
     </message>
     <message>
         <source>Last Play Weight</source>
@@ -460,7 +670,7 @@
     </message>
     <message>
         <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to how long it has been since a given track was played when ordering a group of songs.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;スマート&quot;シャッフルモードで使用されます。再生されてからの時間が曲順に影響します。</translation>
     </message>
     <message>
         <source>Random Weight</source>
@@ -468,7 +678,7 @@
     </message>
     <message>
         <source>Used in &quot;Smart&quot; Shuffle mode. This weighting affects how much strength is given to good old (peudo-)randomness when ordering a group of songs.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;スマート&quot;シャッフルモードで使用されます。</translation>
     </message>
     <message>
         <source>Show Song Ratings</source>
@@ -484,7 +694,7 @@
     </message>
     <message>
         <source>List songs on the playback screen in the order they will be played.</source>
-        <translation type="unfinished"></translation>
+        <translation>再生画面に再生される順に表示する</translation>
     </message>
     <message>
         <source>Show entire music tree</source>
@@ -492,7 +702,7 @@
     </message>
     <message>
         <source>If selected, you can navigate your entire music tree from the playing screen.</source>
-        <translation type="unfinished"></translation>
+        <translation>これを選択すると、再生に全ての音楽を表示します。</translation>
     </message>
     <message>
         <source>Play mode</source>
@@ -512,7 +722,7 @@
     </message>
     <message>
         <source>Starting shuffle mode for the player.  Can be either normal, random, or intelligent (random).</source>
-        <translation type="unfinished"></translation>
+        <translation>再生時のシャッフルモード。ノーマル、ランダム、インテリジェント（ランダム）から選択できます。</translation>
     </message>
     <message>
         <source>Delay before Visualizations start (seconds)</source>
@@ -536,7 +746,7 @@
     </message>
     <message>
         <source>If set to &quot;2&quot;, visualizations will be scaled in half.  Currently only used by the goom visualization.  Reduces CPU load on slower machines.</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;2&quot;をセットするとビジュアリゼーションは半分のサイズになります。現在はグームのみ有効です。遅いマシンでCPU負荷を減らします。</translation>
     </message>
     <message>
         <source>Height for Visual Scaling</source>
@@ -548,35 +758,35 @@
     </message>
     <message>
         <source>List of visualizations to use during playback. Possible values are space-separated list of </source>
-        <translation type="unfinished"></translation>
+        <translation>再生中に使用するビジュアリゼーションのリスト。スペース区切りで並べてください。</translation>
     </message>
     <message>
         <source>MonoScope</source>
-        <translation type="unfinished"></translation>
+        <translation>モノスコープ</translation>
     </message>
     <message>
         <source>StereoScope</source>
-        <translation type="unfinished"></translation>
+        <translation>ステレオスコープ</translation>
     </message>
     <message>
         <source>Spectrum</source>
-        <translation type="unfinished"></translation>
+        <translation>スペクトラム</translation>
     </message>
     <message>
         <source>Goom</source>
-        <translation type="unfinished"></translation>
+        <translation>グーム</translation>
     </message>
     <message>
         <source>Synaesthesia</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <source>Gears</source>
-        <translation type="unfinished"></translation>
+        <translation>ギア</translation>
     </message>
     <message>
         <source>Blank</source>
-        <translation type="unfinished"></translation>
+        <translation>ブランク</translation>
     </message>
     <message>
         <source>Default Rip Quality</source>
@@ -620,7 +830,7 @@
     </message>
     <message>
         <source>MPEG Layer 1/2/3 Audio (MAD decoder)</source>
-        <translation type="unfinished"></translation>
+        <translation>MPEG レイヤー 1/2/3 オーディオ (MAD デコーダー)</translation>
     </message>
     <message>
         <source>music database</source>
@@ -732,7 +942,7 @@ You have no MythMusic tables in your database.</source>
     </message>
     <message>
         <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
-        <translation type="unfinished"></translation>
+        <translation>これをセットすると、MP3エンコーダーは低品質のときを除いて可変ビットレート(VBR)を使用します。Oggエンコーダーは常に可変ビットレートです。</translation>
     </message>
     <message>
         <source>AlbumArt</source>
@@ -756,7 +966,7 @@ You have no MythMusic tables in your database.</source>
     </message>
     <message>
         <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
-        <translation type="unfinished"></translation>
+        <translation>CD書き込みするSCSIデバイスを選択してください。  IDEデバイスがない場合は起動オプションのhdd(又はhdc/hdb)=ide-scsiを試してください</translation>
     </message>
     <message>
         <source>Disk Size</source>
@@ -776,7 +986,7 @@ You have no MythMusic tables in your database.</source>
     </message>
     <message>
         <source>Enable directories on MP3 Creation</source>
-        <translation type="unfinished"></translation>
+        <translation>MP3作成時にディレクトリを使用する</translation>
     </message>
     <message>
         <source>CD Write Speed</source>
@@ -848,7 +1058,11 @@ You have no MythMusic tables in your database.</source>
     </message>
     <message>
         <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
-        <translation type="unfinished"></translation>
+        <translation>ミュージックツリーの並べ方。スペース区切りでキーワードを指定してください。使用できるキーワードは genre, splitartist, artist, album, と title です。</translation>
+    </message>
+    <message>
+        <source>CD: %1 ~ %2 - %3</source>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -905,6 +1119,273 @@ You have no MythMusic tables in your database.</source>
         <source>Ripping...</source>
         <translation>リッピング...</translation>
     </message>
+    <message>
+        <source>Multi-Artist?</source>
+        <translation>複数のアーチスト?</translation>
+    </message>
+    <message>
+        <source>Switch Titles &amp;&amp; Artists</source>
+        <translation>タイトルとアーチストを交換</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>タイトル</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation>アーティスト</translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation>時間</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLCriteriaRow</name>
+    <message>
+        <source>Select an Artist</source>
+        <translation>アーチストを選択</translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation>アルバムを選択</translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation>ジャンルを選択</translation>
+    </message>
+    <message>
+        <source>Select a Title</source>
+        <translation>タイトルを選択</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLOrderByDialog</name>
+    <message>
+        <source>Order By Fields</source>
+        <translation>フィールド順</translation>
+    </message>
+    <message>
+        <source>1 Add</source>
+        <translation>1 追加</translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation>追加</translation>
+    </message>
+    <message>
+        <source>2 Delete</source>
+        <translation>2 削除</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>削除</translation>
+    </message>
+    <message>
+        <source>3 Move Up</source>
+        <translation>3 上に移動</translation>
+    </message>
+    <message>
+        <source>Move Up</source>
+        <translation>上に移動</translation>
+    </message>
+    <message>
+        <source>4 Move Down</source>
+        <translation>4 下に移動</translation>
+    </message>
+    <message>
+        <source>Move Down</source>
+        <translation>下に移動</translation>
+    </message>
+    <message>
+        <source>5 Ascending</source>
+        <translation>5 昇順</translation>
+    </message>
+    <message>
+        <source>Ascending</source>
+        <translation>昇順</translation>
+    </message>
+    <message>
+        <source>6 Descending</source>
+        <translation>6 降順</translation>
+    </message>
+    <message>
+        <source>Descending</source>
+        <translation>昇順</translation>
+    </message>
+    <message>
+        <source>7 OK</source>
+        <translation>7 決定</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>決定</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLResultViewer</name>
+    <message>
+        <source>Smart Playlist Result Viewer</source>
+        <translation>スマートプレイリストビューワー</translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation>編集</translation>
+    </message>
+    <message>
+        <source>ID</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation>アーティスト</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation>アルバム</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>タイトル</translation>
+    </message>
+    <message>
+        <source>Genre</source>
+        <translation>ジャンル</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>年</translation>
+    </message>
+    <message>
+        <source>Track No.</source>
+        <translation>トラックNo.</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistDialog</name>
+    <message>
+        <source>Smart Playlists</source>
+        <translation>スマートプレイリスト</translation>
+    </message>
+    <message>
+        <source>1 Select</source>
+        <translation>1 選択</translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation>選択</translation>
+    </message>
+    <message>
+        <source>2 New</source>
+        <translation>2 新規</translation>
+    </message>
+    <message>
+        <source>New</source>
+        <translation>新規</translation>
+    </message>
+    <message>
+        <source>3 Edit</source>
+        <translation>3 編集</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>編集</translation>
+    </message>
+    <message>
+        <source>4 Delete</source>
+        <translation>4 削除</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>削除</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this SmartPlaylist?</source>
+        <translation>このスマートプレイリストを削除してよろしいですか?</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistEditor</name>
+    <message>
+        <source>Smart Playlist Editor</source>
+        <translation>スマートプレイリスト編集</translation>
+    </message>
+    <message>
+        <source>Category:</source>
+        <translation>カテゴリー:</translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation>タイトル:</translation>
+    </message>
+    <message>
+        <source>Match</source>
+        <translation>検索方法</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>全て</translation>
+    </message>
+    <message>
+        <source>Any</source>
+        <translation>どれか</translation>
+    </message>
+    <message>
+        <source>Of The Following Conditions</source>
+        <translation>下の条件に一致</translation>
+    </message>
+    <message>
+        <source>Order By:</source>
+        <translation>並び順:</translation>
+    </message>
+    <message>
+        <source>Matches:</source>
+        <translation>一致結果:</translation>
+    </message>
+    <message>
+        <source>Limit:</source>
+        <translation>リミット:</translation>
+    </message>
+    <message>
+        <source></source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>キャンセル</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>保存</translation>
+    </message>
+    <message>
+        <source>Show Results</source>
+        <translation>結果を表示する</translation>
+    </message>
+    <message>
+        <source>Smart Playlist Categories</source>
+        <translation>スマートプレイリストのカテゴリー</translation>
+    </message>
+    <message>
+        <source>New Category</source>
+        <translation>新しいカテゴリー</translation>
+    </message>
+    <message>
+        <source>Delete Category</source>
+        <translation>カテゴリーを削除</translation>
+    </message>
+    <message>
+        <source>Rename Category</source>
+        <translation>カテゴリーの名前を変更</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this Category?</source>
+        <translation>このカテゴリーを削除してよろしいですか?</translation>
+    </message>
+    <message>
+        <source>It will also delete any Smart Playlists belonging to this category.</source>
+        <translation>関連するスマートプレイリストも削除されます。</translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -912,5 +1393,53 @@ You have no MythMusic tables in your database.</source>
         <source>Please Wait...</source>
         <translation>お待ちください ...</translation>
     </message>
+    <message>
+        <source>Track Information</source>
+        <translation>トラック情報</translation>
+    </message>
+    <message>
+        <source>Artist:</source>
+        <translation>アーチスト:</translation>
+    </message>
+    <message>
+        <source>Album:</source>
+        <translation>アルバム:</translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation>タイトル:</translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation>ジャンル:</translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation>年:</translation>
+    </message>
+    <message>
+        <source>Track No.:</source>
+        <translation>トラックNo:</translation>
+    </message>
+    <message>
+        <source>Rating:</source>
+        <translation>レイティング:</translation>
+    </message>
+    <message>
+        <source>Play Count:</source>
+        <translation>プレイカウント:</translation>
+    </message>
+    <message>
+        <source>Last Play:</source>
+        <translation>ラストプレイ:</translation>
+    </message>
+    <message>
+        <source>Compilation:</source>
+        <translation>編集:</translation>
+    </message>
+    <message>
+        <source>Filename:</source>
+        <translation>ファイル名:</translation>
+    </message>
 </context>
 </TS>
