@@ -1,10 +1,6 @@
 <!DOCTYPE TS><TS>
 <context>
     <name>DatabaseBox</name>
-    <message>
-        <source>Select music to be played:</source>
-        <translation type="obsolete">Välj musik som skall spelas:</translation>
-    </message>
     <message>
         <source>Active Play Queue</source>
         <translation>Aktiv spellista</translation>
@@ -111,12 +107,75 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Genre: </source>
         <translation>Genre: </translation>
     </message>
+    <message>
+        <source>Compilation Artist:<byte value="x9"/></source>
+        <translation>Kompileringsartist:<byte value="x9"/></translation>
+    </message>
 </context>
 <context>
-    <name>PlaybackBox</name>
+    <name>EditMetadataDialog</name>
+    <message>
+        <source>Done</source>
+        <translation>Klar</translation>
+    </message>
+    <message>
+        <source>DB Statistics</source>
+        <translation>DB-statistik</translation>
+    </message>
+    <message>
+        <source>Various Artists</source>
+        <translation>Blandade artister</translation>
+    </message>
+    <message>
+        <source>Select an Artist</source>
+        <translation>Välj en artist</translation>
+    </message>
+    <message>
+        <source>Select a Compilation Artist</source>
+        <translation>Välj en kompileringsartist</translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation>Välj ett album</translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation>Välj en genre</translation>
+    </message>
+    <message>
+        <source>Save Changes?</source>
+        <translation>Spara ändringar?</translation>
+    </message>
+    <message>
+        <source>Save to Database Only</source>
+        <translation>Spara endast till databas</translation>
+    </message>
+    <message>
+        <source>Save to File Only</source>
+        <translation>Spara endast till fil</translation>
+    </message>
+    <message>
+        <source>Save to File and Database</source>
+        <translation>Spara till fil och databas</translation>
+    </message>
+    <message>
+        <source>Exit/Do Not Save</source>
+        <translation>Avsluta/Spara inte</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to save the modified metadata to the file?</source>
+        <translation>Är du säker på att du vill spara ändrad metadata till filen?</translation>
+    </message>
+</context>
+<context>
+    <name>PlaybackBoxMusic</name>
     <message>
         <source>Edit Playlist</source>
-        <translation>Editera spellista</translation>
+        <translation>Redigera spellista</translation>
     </message>
     <message>
         <source>Visualize</source>
@@ -222,6 +281,30 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Decoder error.</source>
         <translation>Avkodningsfel.</translation>
     </message>
+    <message>
+        <source>Smart playlists</source>
+        <translation>Smarta spellistor</translation>
+    </message>
+    <message>
+        <source>All Tracks</source>
+        <translation>Alla spår</translation>
+    </message>
+    <message>
+        <source>Tracks by current Artist</source>
+        <translation>Spår av aktuell artist</translation>
+    </message>
+    <message>
+        <source>Tracks from current Album</source>
+        <translation>Spår från aktuellt album</translation>
+    </message>
+    <message>
+        <source>Tracks from current Genre</source>
+        <translation>Spår från aktuell genre</translation>
+    </message>
+    <message>
+        <source>Tracks from current Year</source>
+        <translation>Spår från aktuellt år</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -273,12 +356,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Tree Sorting</source>
         <translation>Trädsortering</translation>
     </message>
-    <message>
-        <source>Order in which to sort the Music Selection Tree. Possible values are space-separated list of genre, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the actual directory tree.</source>
-        <translation type="obsolete">Den ordning som trädet för musikval sorteras i. Möjliga värden är:
-* Mellanslagsseparerad lista med &apos;genre&apos;, &apos;artist&apos;, &apos;album&apos; och &apos;title&apos;
-* &apos;directory&apos; (=katalog), vilket betyder att trädet speglar den faktiska katalogstrukturen.</translation>
-    </message>
     <message>
         <source>Script Path</source>
         <translation>Sökväg för skript</translation>
@@ -579,26 +656,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Updating music database</source>
         <translation>Uppdaterar musikdatabas</translation>
     </message>
-    <message>
-        <source>music database</source>
-        <translation type="obsolete">musikdatabas</translation>
-    </message>
-    <message>
-        <source>cd ripper</source>
-        <translation type="obsolete">cd-kopierare</translation>
-    </message>
-    <message>
-        <source>
-
-You have no MythMusic tables in your database.</source>
-        <translation type="obsolete">
-
-Du har inga tabeller för Musikspelaren (MythMusic) i din databas.</translation>
-    </message>
-    <message>
-        <source>OK, I&apos;ll read the documentation</source>
-        <translation type="obsolete">OK, jag skall läsa dokumentationen</translation>
-    </message>
     <message>
         <source>Unknown Artist</source>
         <translation>Okänd artist</translation>
@@ -633,7 +690,7 @@ Du har inga tabeller för Musikspelaren (MythMusic) i din databas.</translation>
     </message>
     <message>
         <source> ~ </source>
-        <translation>~</translation>
+        <translation> ~ </translation>
     </message>
     <message>
         <source>Ooops</source>
@@ -809,6 +866,10 @@ Du har inga tabeller för Musikspelaren (MythMusic) i din databas.</translation>
 * Mellanslagsseparerad lista med &apos;genre&apos;, &apos;splitartist&apos;, &apos;artist&apos;, &apos;album&apos; och &apos;title&apos;
 * &apos;directory&apos; (=katalog), vilket betyder att trädet speglar den faktiska katalogstrukturen.</translation>
     </message>
+    <message>
+        <source>CD: %1 ~ %2 - %3</source>
+        <translation>CD: %1 ~ %2 - %3</translation>
+    </message>
 </context>
 <context>
     <name>Ripper</name>
@@ -864,6 +925,273 @@ Du har inga tabeller för Musikspelaren (MythMusic) i din databas.</translation>
         <translation>Kopierar från CD:
 </translation>
     </message>
+    <message>
+        <source>Multi-Artist?</source>
+        <translation>Flera artister?</translation>
+    </message>
+    <message>
+        <source>Switch Titles &amp;&amp; Artists</source>
+        <translation>Växla Titlar &amp;&amp; Artister</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titel</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation>Artist</translation>
+    </message>
+    <message>
+        <source>Length</source>
+        <translation>Längd</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLCriteriaRow</name>
+    <message>
+        <source>Select an Artist</source>
+        <translation>Välj en artist</translation>
+    </message>
+    <message>
+        <source>Select an Album</source>
+        <translation>Välj ett album</translation>
+    </message>
+    <message>
+        <source>Select a Genre</source>
+        <translation>Välj en genre</translation>
+    </message>
+    <message>
+        <source>Select a Title</source>
+        <translation>Välj en titel</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLOrderByDialog</name>
+    <message>
+        <source>Order By Fields</source>
+        <translation>Sortera efter fält</translation>
+    </message>
+    <message>
+        <source>1 Add</source>
+        <translation>1 Lägg till</translation>
+    </message>
+    <message>
+        <source>Add</source>
+        <translation>Lägg till</translation>
+    </message>
+    <message>
+        <source>2 Delete</source>
+        <translation>2 Radera</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Radera</translation>
+    </message>
+    <message>
+        <source>3 Move Up</source>
+        <translation>3 Flytta upp</translation>
+    </message>
+    <message>
+        <source>Move Up</source>
+        <translation>Flytta upp</translation>
+    </message>
+    <message>
+        <source>4 Move Down</source>
+        <translation>4 Flytta ned</translation>
+    </message>
+    <message>
+        <source>Move Down</source>
+        <translation>Flytta ned</translation>
+    </message>
+    <message>
+        <source>5 Ascending</source>
+        <translation>5 Stigande</translation>
+    </message>
+    <message>
+        <source>Ascending</source>
+        <translation>Stigande</translation>
+    </message>
+    <message>
+        <source>6 Descending</source>
+        <translation>6 Fallande</translation>
+    </message>
+    <message>
+        <source>Descending</source>
+        <translation>Fallande</translation>
+    </message>
+    <message>
+        <source>7 OK</source>
+        <translation>7 OK</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPLResultViewer</name>
+    <message>
+        <source>Smart Playlist Result Viewer</source>
+        <translation>Smart spellistsresultatvisare</translation>
+    </message>
+    <message>
+        <source>Exit</source>
+        <translation>Avsluta</translation>
+    </message>
+    <message>
+        <source>ID</source>
+        <translation>ID</translation>
+    </message>
+    <message>
+        <source>Artist</source>
+        <translation>Artist</translation>
+    </message>
+    <message>
+        <source>Album</source>
+        <translation>Album</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation>Titel</translation>
+    </message>
+    <message>
+        <source>Genre</source>
+        <translation>Genre</translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation>År</translation>
+    </message>
+    <message>
+        <source>Track No.</source>
+        <translation>Spår nr.</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistDialog</name>
+    <message>
+        <source>Smart Playlists</source>
+        <translation>Smarta spellistor</translation>
+    </message>
+    <message>
+        <source>1 Select</source>
+        <translation>1 Välj</translation>
+    </message>
+    <message>
+        <source>Select</source>
+        <translation>Välj</translation>
+    </message>
+    <message>
+        <source>2 New</source>
+        <translation>2 Ny</translation>
+    </message>
+    <message>
+        <source>New</source>
+        <translation>Ny</translation>
+    </message>
+    <message>
+        <source>3 Edit</source>
+        <translation>3 Redigera</translation>
+    </message>
+    <message>
+        <source>Edit</source>
+        <translation>Redigera</translation>
+    </message>
+    <message>
+        <source>4 Delete</source>
+        <translation>4 Radera</translation>
+    </message>
+    <message>
+        <source>Delete</source>
+        <translation>Radera</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this SmartPlaylist?</source>
+        <translation>Är du säker på att du vill radera denna spellista?</translation>
+    </message>
+</context>
+<context>
+    <name>SmartPlaylistEditor</name>
+    <message>
+        <source>Smart Playlist Editor</source>
+        <translation>Smart spellistseditor</translation>
+    </message>
+    <message>
+        <source>Category:</source>
+        <translation>Kategori:</translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation>Titel: </translation>
+    </message>
+    <message>
+        <source>Match</source>
+        <translation>Träff</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation>Alla</translation>
+    </message>
+    <message>
+        <source>Any</source>
+        <translation>Någon</translation>
+    </message>
+    <message>
+        <source>Of The Following Conditions</source>
+        <translation>av följande villkor</translation>
+    </message>
+    <message>
+        <source>Order By:</source>
+        <translation>Ordna efter:</translation>
+    </message>
+    <message>
+        <source>Matches:</source>
+        <translation>Träffar:</translation>
+    </message>
+    <message>
+        <source>Limit:</source>
+        <translation>Gräns:</translation>
+    </message>
+    <message>
+        <source></source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Avbryt</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Spara</translation>
+    </message>
+    <message>
+        <source>Show Results</source>
+        <translation>Visa resultat</translation>
+    </message>
+    <message>
+        <source>Smart Playlist Categories</source>
+        <translation>Smarta spellistskategorier</translation>
+    </message>
+    <message>
+        <source>New Category</source>
+        <translation>Ny kategori</translation>
+    </message>
+    <message>
+        <source>Delete Category</source>
+        <translation>Radera kategori</translation>
+    </message>
+    <message>
+        <source>Rename Category</source>
+        <translation>Byt namn på kategori</translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this Category?</source>
+        <translation>Är du säker på att du vill radera denna kategori?</translation>
+    </message>
+    <message>
+        <source>It will also delete any Smart Playlists belonging to this category.</source>
+        <translation>Alla smarta spellistor som hör till denna kategori raderas också.</translation>
+    </message>
 </context>
 <context>
     <name>ThemeUI</name>
@@ -871,5 +1199,53 @@ Du har inga tabeller för Musikspelaren (MythMusic) i din databas.</translation>
         <source>Please Wait...</source>
         <translation>Vänta...</translation>
     </message>
+    <message>
+        <source>Track Information</source>
+        <translation>Spårinformation</translation>
+    </message>
+    <message>
+        <source>Artist:</source>
+        <translation>Artist: </translation>
+    </message>
+    <message>
+        <source>Album:</source>
+        <translation>Album: </translation>
+    </message>
+    <message>
+        <source>Title:</source>
+        <translation>Titel: </translation>
+    </message>
+    <message>
+        <source>Genre:</source>
+        <translation>Genre: </translation>
+    </message>
+    <message>
+        <source>Year:</source>
+        <translation>År:</translation>
+    </message>
+    <message>
+        <source>Track No.:</source>
+        <translation>Spår nr:</translation>
+    </message>
+    <message>
+        <source>Rating:</source>
+        <translation>Rankning:</translation>
+    </message>
+    <message>
+        <source>Play Count:</source>
+        <translation>Spelantal:</translation>
+    </message>
+    <message>
+        <source>Last Play:</source>
+        <translation>Senast spelad:</translation>
+    </message>
+    <message>
+        <source>Compilation:</source>
+        <translation>Kompilering:</translation>
+    </message>
+    <message>
+        <source>Filename:</source>
+        <translation>Filnamn:</translation>
+    </message>
 </context>
 </TS>
