@@ -146,8 +146,11 @@ DatabaseBox::~DatabaseBox()
     }
 
     all_music->resetListings();
-
-    gContext->GetLCDDevice()->switchToTime();
+    
+    the_playlists->getActive()->removeAllWidgets();
+    
+    if (class LCD * lcd = LCD::Get())
+        lcd->switchToTime();
 
     delete rootNode;
 }
@@ -164,13 +167,16 @@ void DatabaseBox::showWaiting()
 
         QString a_string = tr("All My Music ~ Loading Music Data ");
 
-        // Set Loading Message on the LCD
-        QPtrList<LCDTextItem> textItems;
-        textItems.setAutoDelete(true);
+        if (class LCD * lcd = LCD::Get())
+        {
+            // Set Loading Message on the LCD
+            QPtrList<LCDTextItem> textItems;
+            textItems.setAutoDelete(true);
 
-        textItems.append(new LCDTextItem(1, ALIGN_CENTERED, 
-                         tr("Loading Music Data"), "Generic", false));
-        gContext->GetLCDDevice()->switchToGeneric(&textItems);
+            textItems.append(new LCDTextItem(1, ALIGN_CENTERED, 
+                             tr("Loading Music Data"), "Generic", false));
+            lcd->switchToGeneric(&textItems);
+        }
 
         for (int i = 0; i < numb_wait_dots; i++)
             a_string += ".";
@@ -537,7 +543,7 @@ void DatabaseBox::fillCD(void)
             if (CDCheckItem *track_ptr = dynamic_cast<CDCheckItem*>(uit))
             {
                 track_ptr->setCheck(0);
-                if (the_playlists->checkCDTrack(track_ptr->getID()))
+                if (the_playlists->checkCDTrack(track_ptr->getID() * -1))
                     track_ptr->setCheck(2);
             }
             ++it;
@@ -560,7 +566,9 @@ void DatabaseBox::fillCD(void)
 
 void DatabaseBox::doMenus(UIListGenericTree *item)
 {
-    if (TreeCheckItem *item_ptr = dynamic_cast<TreeCheckItem*>(item))
+    if (dynamic_cast<CDCheckItem*>(item))
+        return;
+    else if (TreeCheckItem *item_ptr = dynamic_cast<TreeCheckItem*>(item))
     {
         if (item_ptr->getID() < 0)
             doPlaylistPopup(item_ptr);
@@ -573,7 +581,8 @@ void DatabaseBox::alternateDoMenus(UIListGenericTree *item, int keypad_number)
 {
     if (TreeCheckItem *item_ptr = dynamic_cast<TreeCheckItem*>(item))
     {
-        if (item_ptr->getID() < 0)
+        bool is_cd = dynamic_cast<CDCheckItem*>(item) != 0;
+        if (item_ptr->getID() < 0 && !is_cd)
             doPlaylistPopup(item_ptr);
         else if (item->getParent())
         {
@@ -581,10 +590,7 @@ void DatabaseBox::alternateDoMenus(UIListGenericTree *item, int keypad_number)
             a_number = (int)(a_number * ( keypad_number / 10.0));
            
             tree->MoveUp(UIListTreeType::MoveMax);
-            for (int i = 0; i < a_number; i++)
-            {
-                tree->MoveDown();
-            }
+            tree->MoveDown(a_number);
         }
     }
     else if (PlaylistTitle *item_ptr = dynamic_cast<PlaylistTitle*>(item))
@@ -596,50 +602,83 @@ void DatabaseBox::entered(UIListTreeType *treetype, UIListGenericTree *item)
     if (!item || !treetype)
         return;
 
+    // Determin if this is a CD entry
+    bool cd = false;
+    if (dynamic_cast<CDCheckItem*>(item))
+      cd = true;
+
     TreeCheckItem *item_ptr = dynamic_cast<TreeCheckItem*>(item);
 
-    if (item_ptr && item->childCount() == 0 && item_ptr->getLevel() == "title")
+    if (item_ptr 
+        && item->childCount() == 0
+        && item_ptr->getLevel() == "title")
     {
         int id = item_ptr->getID();
 
-        Metadata *mdata = all_music->getMetadata(id);
+        Metadata *mdata;
+        if (!cd)
+        {
+            mdata = all_music->getMetadata(id);
+            if (!mdata)
+                return;
+        }
+        else 
+        {
+            // Need to allocate storage for CD Metadata
+            mdata = new Metadata;
+            if (!all_music->getCDMetadata(id, mdata))
+            {
+                delete mdata;
+                return;
+            }
+        }
+        
+        unsigned int line = 0;
+        QString tmpstr;
 
-        if (!mdata)
-            return;
-
-        QString tmpstr = tr("Artist:\t") + mdata->Artist();
-        m_lines.at(0)->SetText(tmpstr);
+        if (mdata->Compilation())
+        {
+            tmpstr = tr("Compilation Artist:\t") + mdata->CompilationArtist();
+            m_lines.at(line++)->SetText(tmpstr);
+        }
+        tmpstr = tr("Artist:\t") + mdata->Artist();
+        m_lines.at(line++)->SetText(tmpstr);
         tmpstr = tr("Album:\t") + mdata->Album();
-        m_lines.at(1)->SetText(tmpstr);
+        m_lines.at(line++)->SetText(tmpstr);
         tmpstr = tr("Title:\t") + mdata->Title();
-        m_lines.at(2)->SetText(tmpstr);
-
-        if (m_lines.at(3))
+        m_lines.at(line++)->SetText(tmpstr);
+        
+        if (m_lines.at(line))
         {
             int maxTime = mdata->Length() / 1000;
-
+            
             int maxh = maxTime / 3600;
             int maxm = (maxTime / 60) % 60;
             int maxs = maxTime % 60;
-
+            
             QString timeStr;
             if (maxh > 0)
                 timeStr.sprintf("%02d:%02d:%02d", maxh, maxm, maxs);
             else
                 timeStr.sprintf("%02d:%02d", maxm, maxs);
-
+            
             tmpstr = tr("Length:\t") + timeStr;
-
+            
             if (mdata->Genre().length() > 0)
             {
                 tmpstr += "            " + tr("Genre: ") + mdata->Genre();
             }
-
-            m_lines.at(3)->SetText(tmpstr);
+            
+            m_lines.at(line)->SetText(tmpstr);
         }
-
-        for (unsigned int i = 4; i < m_lines.count(); i++)
-            m_lines.at(i)->SetText("");
+          
+        // Post increment as not incremented from previous use.
+        while (++line < m_lines.count())
+          m_lines.at(line)->SetText("");
+        
+        // Don't forget to delete the mdata storage if we allocated it.
+        if (cd)
+          delete mdata;
 
         return;
     }
@@ -1170,8 +1209,9 @@ void DatabaseBox::checkTree(UIListGenericTree *startingpoint)
         //  Only check things which are TreeCheckItem's
         if (TreeCheckItem *item = dynamic_cast<TreeCheckItem*>(uit))
         {
+            bool is_cd = dynamic_cast<CDCheckItem*>(uit) != 0;
             item->setCheck(0);
-            if (active_playlist->checkTrack(item->getID()))
+            if (active_playlist->checkTrack(item->getID(), is_cd))
             {
                 //  Turn on if it's on the current playlist
                 item->setCheck(2);
@@ -1211,7 +1251,6 @@ void ReadCDThread::run()
     CdDecoder *decoder = new CdDecoder("cda", NULL, NULL, NULL);
     int tracknum = decoder->getNumCDAudioTracks();
 
-    bool setTitle = false;
     bool redo = false;
 
     if (tracknum != all_music->getCDTrackCount())
@@ -1228,8 +1267,7 @@ void ReadCDThread::run()
         all_music->clearCDData();
         the_playlists->clearCDList();
     }
-
-    if (tracknum > 0)
+    else if (tracknum > 0)
     {
         // Check the last track to see if it's differen than whatever it was 
         // before
@@ -1255,6 +1293,7 @@ void ReadCDThread::run()
     } 
 
     int tracks = decoder->getNumTracks();
+    bool setTitle = false;
 
     for (int actual_tracknum = 1; 
          redo && actual_tracknum <= tracks; actual_tracknum++)
@@ -1268,9 +1307,9 @@ void ReadCDThread::run()
             {
             
                 QString parenttitle = " ";
-                if (track->Artist().length() > 0)
+                if (track->FormatArtist().length() > 0)
                 {
-                    parenttitle += track->Artist();
+                    parenttitle += track->FormatArtist();
                     parenttitle += " ~ "; 
                 }
 
@@ -1298,6 +1337,10 @@ void ReadCDThread::run()
 
 void DatabaseBox::updateLCDMenu(QKeyEvent * e)
 {
+    class LCD * lcd = LCD::Get();
+    if (lcd == NULL)
+        return;
+
     // Update the LCD with a menu of items
     UIListGenericTree *curItem = tree->GetCurrentPosition();
 
@@ -1317,14 +1360,14 @@ void DatabaseBox::updateLCDMenu(QKeyEvent * e)
         buildMenuTree(menuItems, item_ptr, 1);
 
     if (!menuItems->isEmpty())
-        gContext->GetLCDDevice()->switchToMenu(menuItems, "MythMusic", false);
+        lcd->switchToMenu(menuItems, "MythMusic", false);
 
     //release the container
     delete menuItems;
 
     //Were done, so switch back to the time display
     if (e->key() == Key_Escape)
-        gContext->GetLCDDevice()->switchToTime();
+        lcd->switchToTime();
 }
 
 LCDMenuItem *DatabaseBox::buildLCDMenuItem(TreeCheckItem *item_ptr, 
