@@ -1,16 +1,17 @@
 #ifndef FLACDECODER_H_
 #define FLACDECODER_H_
 
-#include "decoder.h"
-
+#define HAVE_INTTYPES_H
 #include <FLAC/all.h>
 
+#include "decoder.h"
+
 class Metadata;
 
 class FlacDecoder : public Decoder
 {
   public:
-    FlacDecoder(const QString &file, DecoderFactory *, QIODevice *, Output *);
+    FlacDecoder(const QString &file, DecoderFactory *, QIODevice *, AudioOutput *);
     virtual ~FlacDecoder(void);
 
     bool initialize();
@@ -42,13 +43,10 @@ class FlacDecoder : public Decoder
     long len, freq, bitrate;
     int chan;
     int bitspersample;
-    unsigned long output_size;
     double totalTime, seekTime;
     unsigned long totalsamples;
 
-    QString getComment(FLAC__StreamMetadata *block, const char *label);
-    void setComment(FLAC__StreamMetadata *block, const char *label,
-                    const QString &data);
+
 };
 
 #endif
