@@ -8,6 +8,7 @@ using namespace std;
 
 #include <mythtv/mythcontext.h>
 #include <mythtv/mythwidgets.h>
+#include <mythtv/mythdbcon.h>
 
 #include "metadata.h"
 
@@ -44,8 +45,11 @@ bool operator!=(const Metadata& a, const Metadata& b)
 Metadata& Metadata::operator=(Metadata *rhs)
 {
     artist = rhs->Artist();
+    compilation_artist = rhs->CompilationArtist();
     album = rhs->Album();
     title = rhs->Title();
+    formattedartist = rhs->FormatArtist();
+    formattedtitle = rhs->FormatTitle();
     genre = rhs->Genre();
     year = rhs->Year();
     tracknum = rhs->Track();
@@ -53,6 +57,7 @@ Metadata& Metadata::operator=(Metadata *rhs)
     rating = rhs->Rating();
     lastplay = rhs->LastPlayStr();
     playcount = rhs->Playcount();
+    compilation = rhs->Compilation();
     id = rhs->ID();
     filename = rhs->Filename();
     changed = rhs->hasChanged();
@@ -60,30 +65,26 @@ Metadata& Metadata::operator=(Metadata *rhs)
     return *this;
 }
 
+QString Metadata::m_startdir = "";
+
+void Metadata::SetStartdir(const QString &dir)
+{
+    Metadata::m_startdir = dir;
+}
+
 void Metadata::persist(QSqlDatabase *db)
 {
+    MSqlQuery query(QString::null, db);
+    query.prepare("UPDATE musicmetadata set rating = :RATING , "
+                  "playcount = :PLAYCOUNT , lastplay = :LASTPLAY "
+                  "where intid = :ID ;");
+    query.bindValue(":RATING", rating);
+    query.bindValue(":PLAYCOUNT", playcount);
+    query.bindValue(":LASTPLAY", lastplay);
+    query.bindValue(":ID", id);
 
-    QString sqlfilename = filename;
-    sqlfilename.replace(QRegExp("\\\\"), QString("\\\\"));
-    sqlfilename.replace(QRegExp("\""), QString("\\\""));
-
-    QString thequery = QString("UPDATE musicmetadata set "
-                               "rating = %1 , "
-                               "playcount = %2 , "
-                               "lastplay = \"%3\" "
-                               "where intid = %4 ;")
-                               .arg(rating)
-                               .arg(playcount)
-                               .arg(lastplay, lastplay.length())
-                               .arg(id);
-
-    QSqlQuery query = db->exec(thequery);
-
-    if (query.numRowsAffected() < 1)
-    {
-        cerr << "metadata.o: Had a problem updating metadata. Couldn't find row in database" << endl;
-    }
-    
+    if (!query.exec() || query.numRowsAffected() < 1)
+        MythContext::DBError("music persist", query);
 }
 
 bool Metadata::isInDatabase(QSqlDatabase *db, QString startdir)
@@ -92,32 +93,31 @@ bool Metadata::isInDatabase(QSqlDatabase *db, QString startdir)
 
     QString sqlfilename = filename;
     sqlfilename = filename.remove(0, startdir.length());
-    sqlfilename.replace(QRegExp("\\\\"), QString("\\\\"));
-    sqlfilename.replace(QRegExp("\""), QString("\\\""));
 
-    QString thequery = QString("SELECT artist,album,title,genre,year,tracknum,"
-                               "length,intid,rating,playcount,lastplay FROM "
-                               "musicmetadata WHERE filename = \"%1\";")
-                               .arg(sqlfilename);
+    MSqlQuery query(QString::null, db);
+    query.prepare("SELECT artist,compilation_artist,album,title,genre,year,tracknum,"
+                  "length,intid,rating,playcount,lastplay,compilation FROM "
+                  "musicmetadata WHERE filename = :FILENAME ;");
+    query.bindValue(":FILENAME", sqlfilename.utf8());
 
-    QSqlQuery query = db->exec(thequery);
-
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.size() > 0)
     {
         query.next();
   
-        artist = query.value(0).toString();
-        album = query.value(1).toString();
-        title = query.value(2).toString();
-        genre = query.value(3).toString();
-        year = query.value(4).toInt();
-        tracknum = query.value(5).toInt();
-        length = query.value(6).toInt();
-        id = query.value(7).toUInt();
-        rating = query.value(8).toInt();
-        playcount = query.value(9).toInt();
-        lastplay = query.value(10).toString();
-
+        artist = QString::fromUtf8(query.value(0).toString());
+        compilation_artist = QString::fromUtf8(query.value(1).toString());
+        album = QString::fromUtf8(query.value(2).toString());
+        title = QString::fromUtf8(query.value(3).toString());
+        genre = QString::fromUtf8(query.value(4).toString());
+        year = query.value(5).toInt();
+        tracknum = query.value(6).toInt();
+        length = query.value(7).toInt();
+        id = query.value(8).toUInt();
+        rating = query.value(9).toInt();
+        playcount = query.value(10).toInt();
+        lastplay = query.value(11).toString();
+        compilation = (query.value(12).toInt() > 0);
+        
         retval = true;
     }
 
@@ -128,6 +128,8 @@ void Metadata::dumpToDatabase(QSqlDatabase *db, QString startdir)
 {
     if (artist == "")
         artist = QObject::tr("Unknown Artist");
+    if (compilation_artist == "")
+        compilation_artist = artist; // This should be the same as Artist if blank.
     if (album == "")
         album = QObject::tr("Unknown Album");
     if (title == "")
@@ -135,60 +137,229 @@ void Metadata::dumpToDatabase(QSqlDatabase *db, QString startdir)
     if (genre == "")
         genre = QObject::tr("Unknown Genre");
 
-    title.replace(QRegExp("\\\\"), QString("\\\\"));
-    title.replace(QRegExp("\""), QString("\\\""));
-    artist.replace(QRegExp("\\\\"), QString("\\\\"));
-    artist.replace(QRegExp("\""), QString("\\\""));
-    album.replace(QRegExp("\\\\"), QString("\\\\"));
-    album.replace(QRegExp("\""), QString("\\\""));
-    genre.replace(QRegExp("\\\\"), QString("\\\\"));
-    genre.replace(QRegExp("\""), QString("\\\""));
-
     QString sqlfilename = filename;
     sqlfilename = filename.remove(0, startdir.length());
-    sqlfilename.replace(QRegExp("\\\\"), QString("\\\\"));
-    sqlfilename.replace(QRegExp("\""), QString("\\\""));
 
     // Don't update the database if a song with the exact same
     // metadata is already there
-    QString checkquery = QString("SELECT filename FROM musicmetadata WHERE "
-                                 "( ( artist = \"%1\" ) AND "
-                                 "( album = \"%2\" ) AND ( title = \"%3\" ) "
-                                 "AND ( genre = \"%4\" ) AND "
-                                 "( year = \"%5\" ) AND ( tracknum = \"%6\" ) "
-                                 "AND ( length = \"%7\" ) );")
-                                 .arg(artist.latin1())
-                                 .arg(album.latin1())
-                                 .arg(title.latin1())
-                                 .arg(genre)
-                                 .arg(year)
-                                 .arg(tracknum)
-                                 .arg(length);
-    QSqlQuery query = db->exec(checkquery);
-    if (query.isActive() && query.numRowsAffected() > 0)
+    MSqlQuery query(QString::null, db);
+    query.prepare("SELECT filename FROM musicmetadata WHERE "
+                  "( ( artist = :ARTIST ) AND "
+                  "( compilation_artist = :COMPILATION_ARTIST ) "
+                  "( album = :ALBUM ) AND ( title = :TITLE ) "
+                  "AND ( genre = :GENRE ) AND "
+                  "( year = :YEAR ) AND ( tracknum = :TRACKNUM ) "
+                  "AND ( length = :LENGTH ) );");
+    query.bindValue(":ARTIST", artist.utf8());
+    query.bindValue(":COMPILATION_ARTIST", compilation_artist.utf8());
+    query.bindValue(":ALBUM", album.utf8());
+    query.bindValue(":TITLE", title.utf8());
+    query.bindValue(":GENRE", genre.utf8());
+    query.bindValue(":YEAR", year);
+    query.bindValue(":TRACKNUM", tracknum);
+    query.bindValue(":LENGTH", length);
+
+    if (query.exec() && query.isActive() && query.size() > 0)
         return;
 
-    QString thequery = QString("INSERT INTO musicmetadata (artist,album,title,"
-                               "genre,year,tracknum,length,filename) VALUES "
-                               "(\"%1\",\"%2\",\"%3\",\"%4\",%5,%6,%7,\"%8\");")
-                              .arg(artist.latin1())
-                              .arg(album.latin1())
-                              .arg(title.latin1())
-                              .arg(genre)
-                              .arg(year)
-                              .arg(tracknum)
-                              .arg(length)
-                              .arg(sqlfilename);
-    db->exec(thequery);
+    query.prepare("INSERT INTO musicmetadata (artist,compilation_artist,album,title,"
+                  "genre,year,tracknum,length,filename,compilation) VALUES "
+                  "(:ARTIST, :COMPILATION_ARTIST, :ALBUM, :TITLE, :GENRE, :YEAR, :TRACKNUM, "
+                  ":LENGTH, :FILENAME, :COMPILATION );");
+    query.bindValue(":ARTIST", artist.utf8());
+    query.bindValue(":COMPILATION_ARTIST", compilation_artist.utf8());
+    query.bindValue(":ALBUM", album.utf8());
+    query.bindValue(":TITLE", title.utf8());
+    query.bindValue(":GENRE", genre.utf8());
+    query.bindValue(":YEAR", year);
+    query.bindValue(":TRACKNUM", tracknum);
+    query.bindValue(":LENGTH", length);
+    query.bindValue(":FILENAME", sqlfilename.utf8());
+    query.bindValue(":COMPILATION", compilation);
+
+    query.exec();
 
     // easiest way to ensure we've got 'id' filled.
     fillData(db);
 }
 
+// Default values for formats
+// NB These will eventually be customizable....
+QString Metadata::formatnormalfileartist      = "ARTIST";
+QString Metadata::formatnormalfiletrack       = "TITLE";
+QString Metadata::formatnormalcdartist        = "ARTIST";
+QString Metadata::formatnormalcdtrack         = "TITLE";
+QString Metadata::formatcompilationfileartist = "COMPARTIST";
+QString Metadata::formatcompilationfiletrack  = "TITLE (ARTIST)";
+QString Metadata::formatcompilationcdartist   = "COMPARTIST";
+QString Metadata::formatcompilationcdtrack    = "TITLE (ARTIST)";
+
+void Metadata::setArtistAndTrackFormats()
+{
+    QString tmp;
+    
+    tmp = gContext->GetSetting("MusicFormatNormalFileArtist");
+    if (!tmp.isEmpty())
+        formatnormalfileartist = tmp;
+    
+    tmp = gContext->GetSetting("MusicFormatNormalFileTrack");
+    if (!tmp.isEmpty())
+        formatnormalfiletrack = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatNormalCDArtist");
+    if (!tmp.isEmpty())
+        formatnormalcdartist = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatNormalCDTrack");
+    if (!tmp.isEmpty())
+        formatnormalcdtrack = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatCompilationFileArtist");
+    if (!tmp.isEmpty())
+        formatcompilationfileartist = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatCompilationFileTrack");
+    if (!tmp.isEmpty())
+        formatcompilationfiletrack = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatCompilationCDArtist");
+    if (!tmp.isEmpty())
+        formatcompilationcdartist = tmp;
+        
+    tmp = gContext->GetSetting("MusicFormatCompilationCDTrack");
+    if (!tmp.isEmpty())
+        formatcompilationcdtrack = tmp;
+}
+
+
+bool Metadata::determineIfCompilation(bool cd)
+{ 
+    compilation = (!compilation_artist.isEmpty() 
+                   && artist != compilation_artist);
+    setCompilationFormatting(cd);
+    return compilation;
+}
+
+
+inline QString Metadata::formatReplaceSymbols(const QString &format)
+{
+  QString rv = format;
+  rv.replace(QRegExp("COMPARTIST"), compilation_artist);
+  rv.replace(QRegExp("ARTIST"), artist);
+  rv.replace(QRegExp("TITLE"), title);
+  rv.replace(QRegExp("TRACK"), QString("%1").arg(tracknum, 2));
+  return rv;
+}
+
+
+inline void Metadata::setCompilationFormatting(bool cd)
+{
+    QString format_artist, format_title;
+    
+    if (!compilation
+        || "" == compilation_artist
+        || artist == compilation_artist)
+    {
+        if (!cd)
+        {
+          format_artist = formatnormalfileartist;
+          format_title  = formatnormalfiletrack;
+        }
+        else
+        {
+          format_artist = formatnormalcdartist;
+          format_title  = formatnormalcdtrack;          
+        }
+    }
+    else
+    {
+        if (!cd)
+        {
+          format_artist = formatcompilationfileartist;
+          format_title  = formatcompilationfiletrack;
+        }
+        else
+        {
+          format_artist = formatcompilationcdartist;
+          format_title  = formatcompilationcdtrack;          
+        }
+    }
+
+    // NB Could do some comparisons here to save memory with shallow copies...
+    formattedartist = formatReplaceSymbols(format_artist);
+      
+    formattedtitle = formatReplaceSymbols(format_title);
+}
+
+
+QString Metadata::FormatArtist()
+{
+    if (formattedartist.isEmpty())
+        setCompilationFormatting();
+        
+    return formattedartist;
+}
+
+
+QString Metadata::FormatTitle()
+{
+    if (formattedtitle.isEmpty())
+        setCompilationFormatting();
+
+    return formattedtitle;
+}
+
+
+void Metadata::updateDatabase(QSqlDatabase *db, QString startdir)
+{
+    startdir = startdir; 
+    // only save to DB if something changed
+    //if (!hasChanged())
+    //    return;
+
+    if (artist == "")
+        artist = QObject::tr("Unknown Artist");
+    if (album == "")
+        album = QObject::tr("Unknown Album");
+    if (title == "")
+        title = filename;
+    if (genre == "")
+        genre = QObject::tr("Unknown Genre");
+
+    MSqlQuery query(QString::null, db);
+
+    query.prepare("UPDATE musicmetadata SET artist = :ARTIST, album = :ALBUM, "
+                  "compilation_artist = :COMPILATION_ARTIST, "
+                  "title = :TITLE, genre = :GENRE, year = :YEAR, "
+                  "tracknum = :TRACKNUM, rating = :RATING, " 
+                  "compilation = :COMPILATION "
+                  "WHERE intid = :ID;");
+    query.bindValue(":ARTIST", artist.utf8());
+    query.bindValue(":COMPILATION_ARTIST", compilation_artist.utf8());
+    query.bindValue(":ALBUM", album.utf8());
+    query.bindValue(":TITLE", title.utf8());
+    query.bindValue(":GENRE", genre.utf8());
+    query.bindValue(":YEAR", year);
+    query.bindValue(":TRACKNUM", tracknum);
+    query.bindValue(":RATING", rating);
+    query.bindValue(":COMPILATION", compilation);
+    query.bindValue(":ID", id);
+
+    if (!query.exec())
+         MythContext::DBError("Update musicmetadata", query);
+}
+
+
 void Metadata::setField(const QString &field, const QString &data)
 {
     if (field == "artist")
         artist = data;
+    // myth@colin.guthr.ie: Not sure what calls this method as I can't seem
+    //                      to find anything that does!
+    //                      I've added the compilation_artist stuff here for 
+    //                      completeness.
+    else if (field == "compilation_artist")
+      compilation_artist = data;
     else if (field == "album")
         album = data;
     else if (field == "title")
@@ -203,6 +374,9 @@ void Metadata::setField(const QString &field, const QString &data)
         tracknum = data.toInt();
     else if (field == "length")
         length = data.toInt();
+    else if (field == "compilation")
+        compilation = (data.toInt() > 0);
+    
     else
     {
         cerr << "metadata.o: Something asked me to return data about a field called " << field << endl ;
@@ -257,17 +431,17 @@ void Metadata::getField(const QStringList &tree_levels, QString *data, const QSt
 void Metadata::getField(const QString &field, QString *data)
 {
     if (field == "artist")
-        *data = artist;
+        *data = FormatArtist();
     else if (field == "album")
         *data = album;
     else if (field == "title")
-        *data = title;
+        *data = FormatTitle();
     else if (field == "genre")
         *data = genre;
     else if (field == "splitartist")
     {
         bool set = false;
-        QString firstchar = artist.left(1).upper();
+        QString firstchar = FormatArtist().left(1).upper();
         for (int i = 0; i < kSplitArray_Max; i++)
         {
             if (splitArray[i].testStr.contains(firstchar))
@@ -292,49 +466,47 @@ void Metadata::fillData(QSqlDatabase *db)
     if (title == "")
         return;
 
-    QString sqltitle = title;
-    sqltitle.replace(QRegExp("\\\\"), QString("\\\\"));
-    sqltitle.replace(QRegExp("\""), QString("\\\""));
-
-    QString thequery = "SELECT artist,album,title,genre,year,tracknum,length,"
-                       "filename,intid,rating,playcount,lastplay FROM "
-                       "musicmetadata WHERE title=\"" + sqltitle + "\"";
+    QString thequery = "SELECT artist,compilation_artist,album,title,genre,year,tracknum,length,"
+                       "filename,intid,rating,playcount,lastplay,compilation "
+                       "FROM musicmetadata WHERE title = :TITLE";
 
     if (album != "")
-    {
-        QString temp = album;
-        temp.replace(QRegExp("\\\\"), QString("\\\\"));
-        temp.replace(QRegExp("\""), QString("\\\""));
-        thequery += " AND album=\"" + temp + "\"";
-    }
+        thequery += " AND album = :ALBUM";
     if (artist != "")
-    {
-        QString temp = artist;
-        temp.replace(QRegExp("\\\\"), QString("\\\\"));
-        temp.replace(QRegExp("\""), QString("\\\""));
-        thequery += " AND artist=\"" + temp + "\"";
-    }
+        thequery += " AND artist = :ARTIST";
+    if (compilation_artist != "")
+        thequery += " AND compilation_artist = :COMPILATION_ARTIST";
 
     thequery += ";";
 
-    QSqlQuery query = db->exec(thequery);
+    MSqlQuery query(QString::null, db);
+    query.prepare(thequery);
+    query.bindValue(":TITLE", title.utf8());
+    query.bindValue(":ALBUM", album.utf8());
+    query.bindValue(":ARTIST", artist.utf8());
+    query.bindValue(":COMPILATION_ARTIST", compilation_artist.utf8());
 
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.size() > 0)
     {
         query.next();
 
-        artist = query.value(0).toString();
-        album = query.value(1).toString();
-        title = query.value(2).toString();
-        genre = query.value(3).toString();
-        year = query.value(4).toInt();
-        tracknum = query.value(5).toInt();
-        length = query.value(6).toInt();
-        filename = query.value(7).toString();
-        id = query.value(8).toUInt();
-        rating = query.value(9).toInt();
-        playcount = query.value(10).toInt();
-        lastplay = query.value(11).toString();
+        artist = QString::fromUtf8(query.value(0).toString());
+        compilation_artist = QString::fromUtf8(query.value(1).toString());
+        album = QString::fromUtf8(query.value(2).toString());
+        title = QString::fromUtf8(query.value(3).toString());
+        genre = QString::fromUtf8(query.value(4).toString());
+        year = query.value(5).toInt();
+        tracknum = query.value(6).toInt();
+        length = query.value(7).toInt();
+        filename = QString::fromUtf8(query.value(8).toString());
+        id = query.value(9).toUInt();
+        rating = query.value(10).toInt();
+        playcount = query.value(11).toInt();
+        lastplay = query.value(12).toString();
+        compilation = (query.value(13).toInt() > 0);
+
+        if (!filename.contains("://"))
+            filename = m_startdir + filename;
     }
 }
 
@@ -343,29 +515,33 @@ void Metadata::fillDataFromID(QSqlDatabase *db)
     if (id == 0)
         return; 
         
-    QString thequery;
-    thequery = QString("SELECT title,artist,album,title,genre,year,tracknum,"
-                       "length,filename,rating,playcount,lastplay FROM "
-                       "musicmetadata WHERE intid=%1;").arg(id);
+    MSqlQuery query(QString::null, db);
+    query.prepare("SELECT title,artist,compilation_artist,album,title,genre,year,tracknum,"
+                  "length,filename,rating,playcount,lastplay,compilation FROM "
+                  "musicmetadata WHERE intid = :ID ;");
+    query.bindValue(":ID", id);
         
-    QSqlQuery query = db->exec(thequery);
-
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.numRowsAffected() > 0)
     {
         query.next();
 
-        title = query.value(0).toString();
-        artist = query.value(1).toString();
-        album = query.value(2).toString();
-        title = query.value(3).toString();
-        genre = query.value(4).toString();
-        year = query.value(5).toInt();
-        tracknum = query.value(6).toInt();
-        length = query.value(7).toInt();
-        filename = query.value(8).toString();
-        rating = query.value(9).toInt();
-        playcount = query.value(10).toInt();
-        lastplay = query.value(11).toString();
+        title = QString::fromUtf8(query.value(0).toString());
+        artist = QString::fromUtf8(query.value(1).toString());
+        compilation_artist = QString::fromUtf8(query.value(2).toString());
+        album = QString::fromUtf8(query.value(3).toString());
+        title = QString::fromUtf8(query.value(4).toString());
+        genre = QString::fromUtf8(query.value(5).toString());
+        year = query.value(6).toInt();
+        tracknum = query.value(7).toInt();
+        length = query.value(8).toInt();
+        filename = QString::fromUtf8(query.value(9).toString());
+        rating = query.value(10).toInt();
+        playcount = query.value(11).toInt();
+        lastplay = query.value(12).toString();
+        compilation = (query.value(13).toInt() > 0);
+
+        if (!filename.contains("://"))
+            filename = m_startdir + filename;
     }
 }
 
@@ -488,9 +664,9 @@ bool AllMusic::cleanOutThreads()
 void AllMusic::resync()
 {
     done_loading = false;
-    QString aquery =    "SELECT intid, artist, album, title, genre, "
+    QString aquery =    "SELECT intid, artist, compilation_artist, album, title, genre, "
                         "year, tracknum, length, filename, rating, "
-                        "lastplay, playcount FROM musicmetadata "
+                        "lastplay, playcount, compilation FROM musicmetadata "
                         "ORDER BY intid;";
 
     QString filename;
@@ -499,32 +675,34 @@ void AllMusic::resync()
     if (!startdir.endsWith("/"));
         startdir += "/";
 
-    QSqlQuery query = db->exec(aquery);
+    MSqlQuery query = db->exec(aquery);
 
     all_music.clear();
     
-    if(query.isActive() && query.numRowsAffected() > 0)
+    if (query.isActive() && query.size() > 0)
     {
-        while(query.next())
+        while (query.next())
         {
-            filename = query.value(8).toString();
+            filename = QString::fromUtf8(query.value(9).toString());
             if (!filename.contains("://"))
                 filename = startdir + filename;
 
             Metadata *temp = new Metadata
                                     (
                                         filename,
-                                        query.value(1).toString(),
-                                        query.value(2).toString(),
-                                        query.value(3).toString(),
-                                        query.value(4).toString(),
-                                        query.value(5).toInt(),
+                                        QString::fromUtf8(query.value(1).toString()),
+                                        QString::fromUtf8(query.value(2).toString()),
+                                        QString::fromUtf8(query.value(3).toString()),
+                                        QString::fromUtf8(query.value(4).toString()),
+                                        QString::fromUtf8(query.value(5).toString()),
                                         query.value(6).toInt(),
                                         query.value(7).toInt(),
+                                        query.value(8).toInt(),
                                         query.value(0).toInt(),
-                                        query.value(9).toInt(),
-                                        query.value(11).toInt(),
-                                        query.value(10).toString()
+                                        query.value(10).toInt(),
+                                        query.value(12).toInt(),
+                                        query.value(11).toString(),
+                                        (query.value(13).toInt() > 0)
                                     );
             all_music.append(temp); //  Don't delete temp, as PtrList now owns it
 
@@ -543,14 +721,7 @@ void AllMusic::resync()
     }
     else
     {
-        if(query.isActive())
-        {
-            cerr << "metadata.o: Your database is out of whack. This is not good." << endl ;
-        }
-        else
-        {
-            cerr << "metadata.o: Your don't seem to have any tracks. That's ok with me if it's ok with you." << endl; 
-        }
+        cerr << "metadata.o: You don't seem to have any tracks. That's ok with me if it's ok with you." << endl; 
     }    
  
     //  To find this data quickly, build a map
@@ -740,7 +911,7 @@ void AllMusic::putCDOnTheListView(CDCheckItem *where)
         QString title_string = "";
         if((*anit).Title().length() > 0)
         {
-            title_string = (*anit).Title();
+            title_string = (*anit).FormatTitle();
         }
         else
         {
@@ -748,7 +919,8 @@ void AllMusic::putCDOnTheListView(CDCheckItem *where)
         }
         QString title_temp = QString(QObject::tr("%1 - %2")).arg((*anit).Track()).arg(title_string);
         QString level_temp = QObject::tr("title");
-        CDCheckItem *new_item = new CDCheckItem(where, title_temp, level_temp, (*anit).Track());
+        CDCheckItem *new_item = new CDCheckItem(where, title_temp, level_temp, 
+                                                -(*anit).Track());
         new_item->setCheck(false); //  Avoiding -Wall     
     }  
 }
@@ -807,9 +979,9 @@ QString AllMusic::getLabel(int an_id, bool *error_flag)
             return a_label;
         }
       
-        a_label += music_map[an_id]->Artist();
+        a_label += music_map[an_id]->FormatArtist();
         a_label += QObject::tr(" ~ ");
-        a_label += music_map[an_id]->Title();
+        a_label += music_map[an_id]->FormatTitle();
     
 
         if(a_label.length() < 1)
@@ -830,7 +1002,7 @@ QString AllMusic::getLabel(int an_id, bool *error_flag)
         {
             if( (*anit).Track() == an_id * -1)
             {
-                a_label = QString(QObject::tr("%1 ~ %2")).arg((*anit).Artist()).arg((*anit).Title());
+                a_label = QString(QObject::tr("CD: %1 ~ %2 - %3")).arg((*anit).FormatArtist()).arg((*anit).Track()).arg((*anit).FormatTitle());
                 *error_flag = false;
                 return a_label;
             }
@@ -865,6 +1037,20 @@ Metadata* AllMusic::getMetadata(int an_id)
     return NULL;
 }
 
+bool AllMusic::updateMetadata(int an_id, Metadata *the_track)
+{
+    if(an_id > 0)
+    {
+        Metadata *mdata = getMetadata(an_id);
+        if (mdata)
+        {
+            *mdata = the_track;
+            return true;    
+        }
+    }
+    return false;
+}
+
 void AllMusic::save()
 {
     //  Check each Metadata entry and save those that 
@@ -896,11 +1082,11 @@ void AllMusic::addCDTrack(Metadata *the_track)
 
 bool AllMusic::checkCDTrack(Metadata *the_track)
 {
-    if(cd_data.count() < 1)
+    if (cd_data.count() < 1)
     {
         return false;
     }
-    if(cd_data.last().Title() == the_track->Title())
+    if (cd_data.last().FormatTitle() == the_track->FormatTitle())
     {
         return true;
     }
@@ -910,9 +1096,9 @@ bool AllMusic::checkCDTrack(Metadata *the_track)
 bool AllMusic::getCDMetadata(int the_track, Metadata *some_metadata)
 {
     ValueMetadata::iterator anit;
-    for(anit = cd_data.begin(); anit != cd_data.end(); ++anit)
+    for (anit = cd_data.begin(); anit != cd_data.end(); ++anit)
     {
-        if( (*anit).Track() == the_track)
+        if ((*anit).Track() == the_track)
         {
             *some_metadata = (*anit);
             return true;
@@ -925,7 +1111,7 @@ bool AllMusic::getCDMetadata(int the_track, Metadata *some_metadata)
 void AllMusic::setSorting(QString a_paths)
 {
     paths = a_paths;
-    if(paths == "directory")
+    if (paths == "directory")
     {
         return;
     }
@@ -934,7 +1120,7 @@ void AllMusic::setSorting(QString a_paths)
         tree_levels = QStringList::split(" ", paths);
     }
     //  Error checking
-    for(QStringList::Iterator it = tree_levels.begin(); it != tree_levels.end(); ++it )
+    for (QStringList::Iterator it = tree_levels.begin(); it != tree_levels.end(); ++it )
     {
         if( *it != "genre"  &&
             *it != "artist" &&
