@@ -5,25 +5,25 @@
 using namespace std;
 
 #include "metadata.h"
-#include "audiooutput.h"
+#include <mythtv/audiooutput.h>
 #include "constants.h"
 #include "streaminput.h"
-#include "output.h"
 #include "decoder.h"
 #include "playbackbox.h"
 #include "databasebox.h"
 #include "mainvisual.h"
+#include "smartplaylist.h"
 
 #include <mythtv/mythcontext.h>
 #include <mythtv/mythwidgets.h>
 #include <mythtv/lcddevice.h>
 
-PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
-                         QString theme_filename, 
-                         PlaylistsContainer *the_playlists,
-                         AllMusic *the_music, const char *name)
+PlaybackBoxMusic::PlaybackBoxMusic(MythMainWindow *parent, QString window_name,
+                                   QString theme_filename, 
+                                   PlaylistsContainer *the_playlists,
+                                   AllMusic *the_music, const char *name)
 
-           : MythThemedDialog(parent, window_name, theme_filename, name)
+                : MythThemedDialog(parent, window_name, theme_filename, name)
 {
     //  A few internal variable defaults
  
@@ -35,6 +35,7 @@ PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
     lcd_update_timer = NULL;
     waiting_for_playlists_timer = NULL;
     playlist_tree = NULL;
+    playlist_popup = NULL;    
     
     lcd_volume_visible = false; 
     isplaying = false;
@@ -47,7 +48,9 @@ PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
     visual_mode_timer = new QTimer(this);
     visualizer_status = 0;
     curMeta = NULL;
-
+    curSmartPlaylistCategory = "";
+    curSmartPlaylistName = "";
+    
     // Set our pointers the playlists and the metadata containers
 
     all_playlists = the_playlists;
@@ -71,11 +74,11 @@ PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
 
     // Possibly (user-defined) control the volume
     
-    volume_control = NULL;
+    volume_control = false;
     volume_display_timer = new QTimer(this);
     if (gContext->GetNumSetting("MythControlsVolume", 0))
     {
-        volume_control = new VolumeControl(true);
+        volume_control = true;
         volume_display_timer->start(2000);
         connect(volume_display_timer, SIGNAL(timeout()), this, SLOT(hideVolume()));
     }
@@ -121,13 +124,16 @@ PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
             vis_button->setText(tr("4 Visualize"));
     }
 
-    // Set please wait on the LCD
-    QPtrList<LCDTextItem> textItems;
-    textItems.setAutoDelete(true);
+    if (class LCD * lcd = LCD::Get())
+    {
+        // Set please wait on the LCD
+        QPtrList<LCDTextItem> textItems;
+        textItems.setAutoDelete(true);
 
-    textItems.append(new LCDTextItem(1, ALIGN_CENTERED, "Please Wait", 
-                     "Generic"));
-    gContext->GetLCDDevice()->switchToGeneric(&textItems);
+        textItems.append(new LCDTextItem(1, ALIGN_CENTERED, "Please Wait", 
+                         "Generic"));
+        lcd->switchToGeneric(&textItems);
+    }
 
     // We set a timer to load the playlists. We do this for two reasons: 
     // (1) the playlists may not be fully loaded, and (2) even if they are 
@@ -180,11 +186,9 @@ PlaybackBox::PlaybackBox(MythMainWindow *parent, QString window_name,
     updateForeground();
 }
 
-PlaybackBox::~PlaybackBox(void)
+PlaybackBoxMusic::~PlaybackBoxMusic(void)
 {
     stopAll();
-    if (volume_control)
-        delete volume_control;
     if (playlist_tree)
         delete playlist_tree;
 
@@ -203,7 +207,7 @@ PlaybackBox::~PlaybackBox(void)
         gContext->SaveSetting("RepeatMode", "none");
 }
 
-void PlaybackBox::keyPressEvent(QKeyEvent *e)
+void PlaybackBoxMusic::keyPressEvent(QKeyEvent *e)
 {
     bool handled = false;
 
@@ -304,6 +308,10 @@ void PlaybackBox::keyPressEvent(QKeyEvent *e)
             changeVolume(true);
         else if (action == "MUTE")
             toggleMute();
+        else if (action == "MENU")
+            showMenu();
+        else if (action == "INFO")
+            showEditMetadataDialog();
         else
             handled = false;
     }
@@ -404,7 +412,218 @@ void PlaybackBox::keyPressEvent(QKeyEvent *e)
         MythThemedDialog::keyPressEvent(e);
 }
 
-void PlaybackBox::checkForPlaylists()
+void PlaybackBoxMusic::showMenu()
+{
+    if (playlist_popup)
+        return;
+
+    playlist_popup = new MythPopupBox(gContext->GetMainWindow(),
+                                      "playlist_popup");
+
+    QButton *button = playlist_popup->addButton(tr("Smart playlists"), this,
+                              SLOT(showSmartPlaylistDialog()));
+    
+    QLabel *splitter = playlist_popup->addLabel(" ", MythPopupBox::Small);
+    splitter->setLineWidth(2);
+    splitter->setFrameShape(QFrame::HLine);
+    splitter->setFrameShadow(QFrame::Sunken);
+    splitter->setMaximumHeight((int) (5 * hmult));
+    splitter->setMaximumHeight((int) (5 * hmult));
+    
+    playlist_popup->addButton(tr("All Tracks"), this,
+                              SLOT(allTracks()));
+    if (curMeta)
+    {
+        playlist_popup->addButton(tr("Tracks by current Artist"), this,
+                                  SLOT(byArtist()));
+        playlist_popup->addButton(tr("Tracks from current Album"), this,
+                                  SLOT(byAlbum()));
+        playlist_popup->addButton(tr("Tracks from current Genre"), this,
+                                  SLOT(byGenre()));
+        playlist_popup->addButton(tr("Tracks from current Year"), this,
+                                  SLOT(byYear()));
+    }
+    
+    playlist_popup->ShowPopup(this, SLOT(closePlaylistPopup()));
+
+    button->setFocus();
+}
+
+void PlaybackBoxMusic::closePlaylistPopup()
+{
+    if (!playlist_popup)
+        return;
+
+    playlist_popup->hide();
+    delete playlist_popup;
+    playlist_popup = NULL;
+}
+
+void PlaybackBoxMusic::allTracks()
+{
+   if (!playlist_popup)
+        return;
+
+    updatePlaylistFromQuickPlaylist("ORDER BY artist, album, tracknum");
+    closePlaylistPopup();
+}
+
+void PlaybackBoxMusic::showSmartPlaylistDialog()
+{
+   if (!playlist_popup)
+        return;
+
+    closePlaylistPopup();
+    
+    SmartPlaylistDialog dialog(gContext->GetMainWindow(), "smartplaylistdialog");
+    dialog.setSmartPlaylist(curSmartPlaylistCategory, curSmartPlaylistName);
+
+    int res = dialog.ExecPopup();
+    
+    if (res > 0)
+    {
+        dialog.getSmartPlaylist(curSmartPlaylistCategory, curSmartPlaylistName);
+        updatePlaylistFromSmartPlaylist(curSmartPlaylistCategory, curSmartPlaylistName);
+    }    
+}    
+
+void PlaybackBoxMusic::byArtist()
+{
+    if (!playlist_popup || !curMeta)
+        return;
+
+    QString value = formattedFieldValue(curMeta->Artist().utf8());
+    QString whereClause = "WHERE artist = " + value +
+                          " ORDER BY album, tracknum"; 
+  
+    updatePlaylistFromQuickPlaylist(whereClause);
+    closePlaylistPopup();
+}
+
+void PlaybackBoxMusic::byAlbum()
+{
+    if (!playlist_popup || !curMeta)
+        return;
+
+    QString value = formattedFieldValue(curMeta->Album().utf8());
+    QString whereClause = "WHERE album = " + value + 
+                          " ORDER BY tracknum";
+    closePlaylistPopup();
+    updatePlaylistFromQuickPlaylist(whereClause);
+}
+
+void PlaybackBoxMusic::byGenre()
+{
+   if (!playlist_popup || !curMeta)
+        return;
+
+    QString value = formattedFieldValue(curMeta->Genre().utf8()); 
+    QString whereClause = "WHERE genre = " + value +
+                          " ORDER BY artist, album, tracknum";   
+    closePlaylistPopup();
+    updatePlaylistFromQuickPlaylist(whereClause);
+}
+
+void PlaybackBoxMusic::byYear()
+{
+   if (!playlist_popup || !curMeta)
+        return;
+
+    QString value = formattedFieldValue(curMeta->Year()); 
+    QString whereClause = "WHERE year = " + value + 
+                          " ORDER BY artist, album, tracknum";
+    
+    updatePlaylistFromQuickPlaylist(whereClause);
+    closePlaylistPopup();
+}
+
+void PlaybackBoxMusic::updatePlaylistFromQuickPlaylist(QString whereClause)
+{
+    QValueList <int> branches_to_current_node;
+    
+    visual_mode_timer->stop();
+
+    all_playlists->getActive()->removeAllTracks();
+    all_playlists->getActive()->fillSonglistFromQuery(whereClause);
+    all_playlists->getActive()->fillSongsFromSonglist();
+    all_playlists->getActive()->postLoad();
+
+    if (visual_mode_delay > 0)
+        visual_mode_timer->start(visual_mode_delay * 1000);
+
+    constructPlaylistTree();
+    
+    stop();
+    wipeTrackInfo();
+    
+    // move to first track in list
+    branches_to_current_node.clear();
+    branches_to_current_node.append(0); //  Root node
+    branches_to_current_node.append(1); //  We're on a playlist (not "My Music")
+    branches_to_current_node.append(0); //  Active play Queue
+    music_tree_list->moveToNodesFirstChild(branches_to_current_node);
+    music_tree_list->refresh();
+}
+
+void PlaybackBoxMusic::updatePlaylistFromSmartPlaylist(QString category, QString name)
+{
+    QValueList <int> branches_to_current_node;
+    
+    visual_mode_timer->stop();
+
+    all_playlists->getActive()->removeAllTracks();
+    all_playlists->getActive()->fillSonglistFromSmartPlaylist(category, name);
+    all_playlists->getActive()->fillSongsFromSonglist();
+    all_playlists->getActive()->postLoad();
+
+    if (visual_mode_delay > 0)
+        visual_mode_timer->start(visual_mode_delay * 1000);
+
+    constructPlaylistTree();
+    
+    stop();
+    wipeTrackInfo();
+    
+    // move to first track in list
+    branches_to_current_node.clear();
+    branches_to_current_node.append(0); //  Root node
+    branches_to_current_node.append(1); //  We're on a playlist (not "My Music")
+    branches_to_current_node.append(0); //  Active play Queue
+    music_tree_list->moveToNodesFirstChild(branches_to_current_node);
+    music_tree_list->refresh();
+}
+
+void PlaybackBoxMusic::showEditMetadataDialog()
+{
+    if(!curMeta)
+    {
+        return;
+    }
+
+    // stop music playing
+    stop();
+    
+    EditMetadataDialog editDialog(curMeta, gContext->GetMainWindow(),
+                      "edit_metadata", "music-", "edit metadata");
+    if (editDialog.exec())
+    {
+        // update the metadata copy stored in all_music
+        if (all_music->updateMetadata(curMeta->ID(), curMeta))
+        {
+           // update the displayed track info
+           GenericTree *node = music_tree_list->getCurrentNode();
+           if (node)
+           {
+               bool errorFlag;
+               node->setString(all_music->getLabel(curMeta->ID(), &errorFlag));
+           }    
+        }   
+    }
+    
+    music_tree_list->select();    
+}
+
+void PlaybackBoxMusic::checkForPlaylists()
 {
     if (first_playlist_check)
     {
@@ -434,7 +653,23 @@ void PlaybackBox::checkForPlaylists()
                 setContext(2);
             updateForeground();
             mainvisual->setVisual(visual_mode);
-        }
+            
+            if(curMeta)
+            {
+                if ( class LCD *lcd = LCD::Get())
+                {
+                    //Show the artist stuff on the LCD
+                    QPtrList<LCDTextItem> textItems;
+                    textItems.setAutoDelete(true);
+
+                    textItems.append(new LCDTextItem(1, ALIGN_CENTERED,
+                                    curMeta->Artist() +" [" + 
+                                    curMeta->Album() + "] " +
+                                    curMeta->Title(), "Generic", true));
+                    lcd->switchToGeneric(&textItems);
+                }
+            }
+        }    
         else
             constructPlaylistTree();
     }
@@ -444,52 +679,54 @@ void PlaybackBox::checkForPlaylists()
     }
 }
 
-void PlaybackBox::changeVolume(bool up_or_down)
+void PlaybackBoxMusic::changeVolume(bool up_or_down)
 {
     if (volume_control)
     {
         if (up_or_down)
-            volume_control->AdjustCurrentVolume(2);
+            output->AdjustCurrentVolume(2);
         else
-            volume_control->AdjustCurrentVolume(-2);
+            output->AdjustCurrentVolume(-2);
         showVolume(true);
     }
 }
 
-void PlaybackBox::toggleMute()
+void PlaybackBoxMusic::toggleMute()
 {
     if (volume_control)
     {
-        volume_control->ToggleMute();
+        output->ToggleMute();
         showVolume(true);
     }
 }
 
-void PlaybackBox::showVolume(bool on_or_off)
+void PlaybackBoxMusic::showVolume(bool on_or_off)
 {
     float volume_level;
-    if (volume_control)
+    if (volume_control && output)
     {
         if (volume_status)
         {
             if(on_or_off)
             {
-                volume_status->SetUsed(volume_control->GetCurrentVolume());
+                volume_status->SetUsed(output->GetCurrentVolume());
                 volume_status->SetOrder(0);
                 volume_status->refresh();
                 volume_display_timer->changeInterval(2000);
                 if (!lcd_volume_visible)
                 {
                     lcd_volume_visible = true;
-                    gContext->GetLCDDevice()->switchToVolume("Music");
+                    if (class LCD * lcd = LCD::Get())
+                        lcd->switchToVolume("Music");
                 }
-                if (volume_control->GetMute())
+                if (output->GetMute())
                     volume_level = 0.0;
                 else
-                    volume_level = (float)volume_control->GetCurrentVolume() / 
+                    volume_level = (float)output->GetCurrentVolume() / 
                                    (float)100;
 
-                gContext->GetLCDDevice()->setVolumeLevel(volume_level);
+                if (class LCD * lcd = LCD::Get())
+                    lcd->setVolumeLevel(volume_level);
             }
             else
             {
@@ -498,31 +735,36 @@ void PlaybackBox::showVolume(bool on_or_off)
                     volume_status->SetOrder(-1);
                     volume_status->refresh();
 
-                    //Show the artist stuff on the LCD
-                    QPtrList<LCDTextItem> textItems;
-                    textItems.setAutoDelete(true);
+                    if (curMeta)
+                    {
+                        if (class LCD * lcd = LCD::Get())
+                        {
+                            //Show the artist stuff on the LCD
+                            QPtrList<LCDTextItem> textItems;
+                            textItems.setAutoDelete(true);
 
-                    textItems.append(new LCDTextItem(1, ALIGN_CENTERED,
-                                     curMeta->Artist() +" [" + 
-                                     curMeta->Album() + "] " +
-                                     curMeta->Title(), "Generic", true));
+                            textItems.append(new LCDTextItem(1, ALIGN_CENTERED,
+                                             curMeta->FormatArtist() +" [" + 
+                                             curMeta->Album() + "] " +
+                                             curMeta->FormatTitle(), "Generic", true));
 
-                    gContext->GetLCDDevice()->switchToGeneric(&textItems);
-
-                    lcd_volume_visible = false;
+                            lcd->switchToGeneric(&textItems);
+                            lcd_volume_visible = false;
+                        }
+                    }
                 }
             }
         }
     }
 }
 
-void PlaybackBox::resetTimer()
+void PlaybackBoxMusic::resetTimer()
 {
     if (visual_mode_delay > 0)
         visual_mode_timer->changeInterval(visual_mode_delay * 1000);
 }
 
-void PlaybackBox::play()
+void PlaybackBoxMusic::play()
 {
     if (isplaying)
         stop();
@@ -545,19 +787,20 @@ void PlaybackBox::play()
     {
         QString adevice = gContext->GetSetting("AudioDevice");
 
-        output = new MMAudioOutput(outputBufferSize * 1024, adevice);
+        // TODO: Error checking that device is opened correctly!
+        output = AudioOutput::OpenAudio(adevice, 16, 2, 44100, 
+	                                 AUDIOOUTPUT_MUSIC, true );	
         output->setBufferSize(outputBufferSize * 1024);
+        output->SetBlocking(false);
         output->addListener(this);
         output->addListener(mainvisual);
         output->addVisual(mainvisual);
 	
         startoutput = true;
 
-        if (!output->initialize())
-            return;
     }
    
-    if (output->isPaused())
+    if (output->GetPause())
     {
         pause();
         return;
@@ -571,7 +814,7 @@ void PlaybackBox::play()
     } 
     else
         input = new QFile(playfile);
-
+    
     if (decoder && !decoder->factory()->supports(sourcename))
         decoder = 0;
 
@@ -605,10 +848,7 @@ void PlaybackBox::play()
     {
         if (output)
         {
-            if (startoutput)
-                output->start();
-            else
-                output->resetTime();
+            output->Reset();
         }
 
         decoder->start();
@@ -619,7 +859,7 @@ void PlaybackBox::play()
     }
 }
 
-void PlaybackBox::visEnable()
+void PlaybackBoxMusic::visEnable()
 {
     if (!visualizer_status != 2 && isplaying)
     {
@@ -629,7 +869,7 @@ void PlaybackBox::visEnable()
     }
 }
 
-void PlaybackBox::CycleVisualizer()
+void PlaybackBoxMusic::CycleVisualizer()
 {
     QString new_visualizer;
 
@@ -679,16 +919,13 @@ void PlaybackBox::CycleVisualizer()
 }
 
 
-void PlaybackBox::pause(void)
+void PlaybackBoxMusic::pause(void)
 {
     if (output) 
     {
-        output->mutex()->lock();
-        output->pause();
         isplaying = !isplaying;
-        output->mutex()->unlock();
+        output->Pause(!isplaying); //Note pause doesn't take effet instantly
     }
-
     // wake up threads
     if (decoder) 
     {
@@ -697,15 +934,9 @@ void PlaybackBox::pause(void)
         decoder->mutex()->unlock();
     }
 
-    if (output) 
-    {
-        output->recycler()->mutex()->lock();
-        output->recycler()->cond()->wakeAll();
-        output->recycler()->mutex()->unlock();
-    }
 }
 
-void PlaybackBox::stopDecoder(void)
+void PlaybackBoxMusic::stopDecoder(void)
 {
     if (decoder && decoder->running()) 
     {
@@ -725,7 +956,7 @@ void PlaybackBox::stopDecoder(void)
         decoder->wait();
 }
 
-void PlaybackBox::stop(void)
+void PlaybackBoxMusic::stop(void)
 {
     if (decoder && decoder->running()) 
     {
@@ -734,13 +965,6 @@ void PlaybackBox::stop(void)
         decoder->mutex()->unlock();
     }
 
-    if (output && output->running()) 
-    {
-        output->mutex()->lock();
-        output->stop();
-        output->mutex()->unlock();
-    }
-
     // wake up threads
     if (decoder) 
     {
@@ -749,19 +973,9 @@ void PlaybackBox::stop(void)
         decoder->mutex()->unlock();
     }
 
-    if (output) 
-    {
-        output->recycler()->mutex()->lock();
-        output->recycler()->cond()->wakeAll();
-        output->recycler()->mutex()->unlock();
-    }
-
     if (decoder)
         decoder->wait();
 
-    if (output)
-        output->wait();
-
     if (output)
     {
         delete output;
@@ -791,9 +1005,13 @@ void PlaybackBox::stop(void)
     isplaying = false;
 }
 
-void PlaybackBox::stopAll()
+void PlaybackBoxMusic::stopAll()
 {
-    gContext->GetLCDDevice()->switchToTime();
+    if (class LCD * lcd = LCD::Get())
+    {
+        lcd->switchToTime();
+    }
+
     stop();
 
     if (decoder) 
@@ -803,7 +1021,7 @@ void PlaybackBox::stopAll()
     }
 }
 
-void PlaybackBox::previous()
+void PlaybackBoxMusic::previous()
 {
     if (repeatmode == REPEAT_ALL)
     {
@@ -820,7 +1038,7 @@ void PlaybackBox::previous()
         CycleVisualizer();
 }
 
-void PlaybackBox::next()
+void PlaybackBoxMusic::next()
 {
     if (repeatmode == REPEAT_ALL)
     {
@@ -840,7 +1058,7 @@ void PlaybackBox::next()
         CycleVisualizer();
 }
 
-void PlaybackBox::nextAuto()
+void PlaybackBoxMusic::nextAuto()
 {
     stopDecoder();
 
@@ -852,7 +1070,7 @@ void PlaybackBox::nextAuto()
         next();
 }
 
-void PlaybackBox::seekforward()
+void PlaybackBoxMusic::seekforward()
 {
     int nextTime = currentTime + 5;
     if (nextTime > maxTime)
@@ -860,7 +1078,7 @@ void PlaybackBox::seekforward()
     seek(nextTime);
 }
 
-void PlaybackBox::seekback()
+void PlaybackBoxMusic::seekback()
 {
     int nextTime = currentTime - 5;
     if (nextTime < 0)
@@ -868,12 +1086,12 @@ void PlaybackBox::seekback()
     seek(nextTime);
 }
 
-void PlaybackBox::seek(int pos)
+void PlaybackBoxMusic::seek(int pos)
 {
-    if (output && output->running()) 
+    if (output)
     {
-        output->mutex()->lock();
-        output->seek(pos);
+        output->Reset();
+        output->SetTimecode(pos*1000);
 
         if (decoder && decoder->running()) 
         {
@@ -889,11 +1107,10 @@ void PlaybackBox::seek(int pos)
 
             decoder->mutex()->unlock();
         }
-        output->mutex()->unlock();
     }
 }
 
-void PlaybackBox::setShuffleMode(unsigned int mode)
+void PlaybackBoxMusic::setShuffleMode(unsigned int mode)
 {
     shufflemode = mode;
 
@@ -938,12 +1155,12 @@ void PlaybackBox::setShuffleMode(unsigned int mode)
     music_tree_list->refresh();
 }
 
-void PlaybackBox::toggleShuffle(void)
+void PlaybackBoxMusic::toggleShuffle(void)
 {
     setShuffleMode(++shufflemode % MAX_SHUFFLE_MODES);
 }
 
-void PlaybackBox::increaseRating()
+void PlaybackBoxMusic::increaseRating()
 {
     if(!curMeta)
         return;
@@ -959,7 +1176,7 @@ void PlaybackBox::increaseRating()
     }
 }
 
-void PlaybackBox::decreaseRating()
+void PlaybackBoxMusic::decreaseRating()
 {
     if(!curMeta)
         return;
@@ -972,7 +1189,7 @@ void PlaybackBox::decreaseRating()
     }
 }
 
-void PlaybackBox::setRepeatMode(unsigned int mode)
+void PlaybackBoxMusic::setRepeatMode(unsigned int mode)
 {
     repeatmode = mode;
 
@@ -1002,12 +1219,12 @@ void PlaybackBox::setRepeatMode(unsigned int mode)
     }
 }
 
-void PlaybackBox::toggleRepeat()
+void PlaybackBoxMusic::toggleRepeat()
 {
     setRepeatMode(++repeatmode % MAX_REPEAT_MODES);
 }
 
-void PlaybackBox::constructPlaylistTree()
+void PlaybackBoxMusic::constructPlaylistTree()
 {
     if (playlist_tree)
         delete playlist_tree;
@@ -1028,7 +1245,7 @@ void PlaybackBox::constructPlaylistTree()
     tree_is_done = true;
 }
 
-void PlaybackBox::editPlaylist()
+void PlaybackBoxMusic::editPlaylist()
 {
     // Get a reference to the current track
 
@@ -1079,7 +1296,7 @@ void PlaybackBox::editPlaylist()
     music_tree_list->refresh();
 }
 
-void PlaybackBox::closeEvent(QCloseEvent *event)
+void PlaybackBoxMusic::closeEvent(QCloseEvent *event)
 {
     stopAll();
 
@@ -1087,12 +1304,12 @@ void PlaybackBox::closeEvent(QCloseEvent *event)
     event->accept();
 }
 
-void PlaybackBox::showEvent(QShowEvent *event)
+void PlaybackBoxMusic::showEvent(QShowEvent *event)
 {
     QWidget::showEvent(event);
 }
 
-void PlaybackBox::customEvent(QCustomEvent *event)
+void PlaybackBoxMusic::customEvent(QCustomEvent *event)
 {
     switch ((int)event->type()) 
     {
@@ -1138,19 +1355,25 @@ void PlaybackBox::customEvent(QCustomEvent *event)
                 time_string.sprintf("%02d:%02d / %02d:%02d", em, es, maxm, 
                                     maxs);
             
-            float percent_heard = ((float)rs / 
-                                   (float)curMeta->Length()) * 1000.0;
-            // Changed to use the Channel stuff as it allows us to
-            // display Artist, Album, and Title, as well as a progress bar
-            gContext->GetLCDDevice()->setGenericProgress(percent_heard);
+            if (curMeta)
+            {
+                if (class LCD * lcd = LCD::Get())
+                {
+                    float percent_heard = ((float)rs / 
+                                           (float)curMeta->Length()) * 1000.0;
+                    // Changed to use the Channel stuff as it allows us to
+                    // display Artist, Album, and Title, as well as a progress bar
+                    lcd->setGenericProgress(percent_heard);
 
-            QPtrList<LCDTextItem> textItems;
-            textItems.setAutoDelete(true);
+                    QPtrList<LCDTextItem> textItems;
+                    textItems.setAutoDelete(true);
 
-            textItems.append(new LCDTextItem(3, ALIGN_RIGHT,
-                                             time_string, "Generic"));
+                    textItems.append(new LCDTextItem(3, ALIGN_RIGHT,
+                                                     time_string, "Generic"));
 
-            gContext->GetLCDDevice()->outputText(&textItems);
+                    lcd->outputText(&textItems);
+                }
+            }
 
             QString info_string;
 
@@ -1231,7 +1454,7 @@ void PlaybackBox::customEvent(QCustomEvent *event)
     QWidget::customEvent(event);
 }
 
-void PlaybackBox::wipeTrackInfo()
+void PlaybackBoxMusic::wipeTrackInfo()
 {
         if (title_text)
             title_text->SetText("");
@@ -1249,7 +1472,7 @@ void PlaybackBox::wipeTrackInfo()
             current_visualization_text->SetText("");
 }
 
-void PlaybackBox::handleTreeListSignals(int node_int, IntVector *attributes)
+void PlaybackBoxMusic::handleTreeListSignals(int node_int, IntVector *attributes)
 {
     if (attributes->size() < 4)
     {
@@ -1264,21 +1487,24 @@ void PlaybackBox::handleTreeListSignals(int node_int, IntVector *attributes)
 
         curMeta = all_music->getMetadata(node_int);
         if (title_text)
-            title_text->SetText(curMeta->Title());
+            title_text->SetText(curMeta->FormatTitle());
         if (artist_text)
-            artist_text->SetText(curMeta->Artist());
+            artist_text->SetText(curMeta->FormatArtist());
         if (album_text)
             album_text->SetText(curMeta->Album());
 
-        // Set the Artist and Tract on the LCD
-        QPtrList<LCDTextItem> textItems;
-        textItems.setAutoDelete(true);
+        if (class LCD * lcd = LCD::Get())
+        {
+            // Set the Artist and Tract on the LCD
+            QPtrList<LCDTextItem> textItems;
+            textItems.setAutoDelete(true);
 
-        textItems.append(new LCDTextItem(1, ALIGN_CENTERED,
-                         curMeta->Artist() + " [" + curMeta->Album() + "] " +
-                         curMeta->Title(), "Generic", true));
+            textItems.append(new LCDTextItem(1, ALIGN_CENTERED,
+                             curMeta->FormatArtist() + " [" + curMeta->Album() + "] " +
+                             curMeta->FormatTitle(), "Generic", true));
 
-        gContext->GetLCDDevice()->outputText(&textItems);
+            lcd->outputText(&textItems);
+        }
 
         maxTime = curMeta->Length() / 1000;
 
@@ -1298,7 +1524,7 @@ void PlaybackBox::handleTreeListSignals(int node_int, IntVector *attributes)
                 ratings_image->setRepeat(curMeta->Rating());
         }
 
-        if (output && output->isPaused())
+        if (output && output->GetPause())
         {
             stop();
             if(play_button)
@@ -1321,7 +1547,7 @@ void PlaybackBox::handleTreeListSignals(int node_int, IntVector *attributes)
 }
 
 
-void PlaybackBox::toggleFullBlankVisualizer()
+void PlaybackBoxMusic::toggleFullBlankVisualizer()
 {
     if( mainvisual->getCurrentVisual() == "Blank" &&
         visualizer_status == 2)
@@ -1363,7 +1589,7 @@ void PlaybackBox::toggleFullBlankVisualizer()
     }
 }
 
-void PlaybackBox::wireUpTheme()
+void PlaybackBoxMusic::wireUpTheme()
 {
     // The self managed music tree list
     //
