@@ -4,9 +4,12 @@ using namespace std;
 #include "playlist.h"
 #include "qdatetime.h"
 #include <mythtv/mythcontext.h>
+#include "smartplaylist.h"
+#include <mythtv/mythdbcon.h>
 
 #include <qfileinfo.h>
 #include <qprocess.h>
+#include <qapplication.h>
 
 Track::Track(int x, AllMusic *all_music_ptr)
 {
@@ -31,11 +34,13 @@ void Track::postLoad(PlaylistsContainer *grandparent)
         else if (index_value > 0) // Normal Track
             label = all_available_music->getLabel(index_value, &bad_reference);
         else if (index_value < 0)
-            label = grandparent->getPlaylistName(index_value * -1, 
+            label = grandparent->getPlaylistName(index_value, 
                                                  bad_reference);
     }
     else
+    {
         label = all_available_music->getLabel(index_value * -1, &bad_reference);
+    }
 }
 
 void Track::setParent(Playlist *parent_ptr)
@@ -60,7 +65,7 @@ void Playlist::postLoad()
     }  
 }
 
-bool Playlist::checkTrack(int a_track_id)
+bool Playlist::checkTrack(int a_track_id, bool cd_flag)
 {
     // XXX SPEED THIS UP
     // Should be a straight lookup against cached index
@@ -69,7 +74,7 @@ bool Playlist::checkTrack(int a_track_id)
 
     for (it = songs.first(); it; it = songs.next())
     {
-        if (it->getValue() == a_track_id)
+        if (it->getValue() == a_track_id && it->getCDFlag() == cd_flag)
         {
             result = true;
         }
@@ -121,7 +126,7 @@ void Track::deleteYourWidget()
 {
     if (my_widget)
     {
-        my_widget->RemoveFromParent();
+       my_widget->RemoveFromParent();
     //    delete my_widget;  Deleted by the parent..
         my_widget = NULL;
     }
@@ -139,6 +144,15 @@ void Playlist::removeAllTracks()
     changed = true;
 }
 
+void Playlist::removeAllWidgets()
+{
+    Track *it;
+    for (it = songs.first(); it; it = songs.next())
+    {
+        it->deleteYourWidget();
+    }
+}
+
 void Playlist::ripOutAllCDTracksNow()
 {
     Track *it;
@@ -321,15 +335,16 @@ void PlaylistsContainer::load()
 
     all_other_playlists->clear();
 
-    QString aquery;
-    aquery = QString("SELECT playlistid FROM musicplaylist "
-                     "WHERE name != \"default_playlist_storage\"  "
-                     "AND name != \"backup_playlist_storage\"  "
-                     "AND hostname = \"%1\" ORDER BY playlistid ;")
-                     .arg(my_host);
+    MSqlQuery query(QString::null, db);
+    query.prepare("SELECT playlistid FROM musicplaylist "
+                  "WHERE name != :DEFAULT  "
+                  "AND name != :BACKUP  "
+                  "AND hostname = :HOST ORDER BY playlistid ;");
+    query.bindValue(":DEFAULT", "default_playlist_storage");
+    query.bindValue(":BACKUP", "backup_playlist_storage"); 
+    query.bindValue(":HOST", my_host);
 
-    QSqlQuery query = db->exec(aquery);
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.size() > 0)
     {
         while (query.next())
         {
@@ -435,10 +450,12 @@ Playlist& Playlist::operator=(const Playlist& rhs)
 void Playlist::describeYourself()
 {
     //  This is for debugging
+/*
     cout << "Playlist with name of \"" << name << "\"" << endl;
     cout << "        playlistid is " << playlistid << endl;
     cout << "     songlist(raw) is \"" << raw_songlist << "\"" << endl;
     cout << "     songlist list is ";
+*/
 
     Track *it;
     for(it = songs.first(); it; it = songs.next())
@@ -459,22 +476,21 @@ void Playlist::loadPlaylist(QString a_name, QSqlDatabase *a_db, QString a_host)
                 "me a hostname!" << endl; 
         return;
     }
-    
-    thequery = QString("SELECT playlistid, name, songlist FROM "
-                       "musicplaylist WHERE name = \"%1\" AND "
-                       "hostname = \"%2\"  ;")
-                      .arg(a_name)
-                      .arg(a_host);
+   
+    MSqlQuery query(QString::null, a_db);
+    query.prepare("SELECT playlistid, name, songlist FROM "
+                  "musicplaylist WHERE name = :NAME AND "
+                  "hostname = :HOST ;");
+    query.bindValue(":NAME", a_name);
+    query.bindValue(":HOST", a_host);
 
-    QSqlQuery somequery = a_db->exec(thequery);
-  
-    if (somequery.numRowsAffected() > 0)
+    if (query.exec() && query.size() > 0)
     {
-        while (somequery.next())
+        while (query.next())
         {
-            this->playlistid = somequery.value(0).toInt();
-            this->name = somequery.value(1).toString();
-            this->raw_songlist = somequery.value(2).toString();
+            this->playlistid = query.value(0).toInt();
+            this->name = QString::fromUtf8(query.value(1).toString());
+            this->raw_songlist = query.value(2).toString();
         }
         if (name == "default_playlist_storage")
             name = "the user should never see this";
@@ -491,19 +507,20 @@ void Playlist::loadPlaylist(QString a_name, QSqlDatabase *a_db, QString a_host)
 
 void Playlist::loadPlaylistByID(int id, QSqlDatabase *a_db, QString a_host)
 {
-    QString thequery;
-    
-    thequery = QString("SELECT playlistid, name, songlist FROM musicplaylist "
-                       "WHERE playlistid = \"%1\" AND hostname=\"%2\" ;")
-                      .arg(id)
-                      .arg(a_host);
-    QSqlQuery somequery = a_db->exec(thequery);
-  
-    while (somequery.next())
+    MSqlQuery query(QString::null, a_db);
+    query.prepare("SELECT playlistid, name, songlist FROM "
+                  "musicplaylist WHERE playlistid = :ID AND "
+                  "hostname = :HOST ;");
+    query.bindValue(":ID", id);
+    query.bindValue(":HOST", a_host);
+
+    query.exec();
+
+    while (query.next())
     {
-        this->playlistid = somequery.value(0).toInt();
-        this->name = somequery.value(1).toString();
-        this->raw_songlist = somequery.value(2).toString();
+        this->playlistid = query.value(0).toInt();
+        this->name = QString::fromUtf8(query.value(1).toString());
+        this->raw_songlist = query.value(2).toString();
     }
 
     if (name == "default_playlist_storage")
@@ -557,6 +574,115 @@ void Playlist::fillSonglistFromSongs()
     raw_songlist = a_list;
 }
 
+void Playlist::fillSonglistFromQuery(QString whereClause)
+{
+    QSqlDatabase *db_conn = QSqlDatabase::database();
+    MSqlQuery query(QString::null, db_conn);
+
+    QString theQuery;
+
+    theQuery = "SELECT intid FROM musicmetadata ";
+    
+    if (whereClause.length() > 0)
+      theQuery += whereClause;
+
+    if (!query.exec(theQuery))
+    {    
+        MythContext::DBError("Load songlist from query", query);
+        raw_songlist = "";
+        return;
+    }
+    
+    raw_songlist = "";
+    while (query.next())
+    {
+        raw_songlist += ", " + query.value(0).toString();
+    }
+    raw_songlist.remove(0, 2);
+}
+
+void Playlist::fillSonglistFromSmartPlaylist(QString category, QString name)
+{
+    QSqlDatabase *db_conn = QSqlDatabase::database();
+    MSqlQuery query(QString::null, db_conn);
+
+    // find the correct categoryid
+    int categoryID = SmartPlaylistEditor::lookupCategoryID(category);
+    if (categoryID == -1)
+    {
+        cout << "Cannot find Smartplaylist Category: " << category << endl;
+        return;
+    }
+    
+    // find smartplaylist
+    int ID;
+    QString matchType;
+    QString orderBy; 
+    int limitTo;
+    
+    query.prepare("SELECT smartplaylistid, matchtype, orderby, limitto "
+                  "FROM smartplaylist WHERE categoryid = :CATEGORYID AND name = :NAME;");
+    query.bindValue(":NAME", name.utf8());
+    query.bindValue(":CATEGORYID", categoryID);
+        
+    if (query.exec())
+    {
+        if (query.isActive() && query.numRowsAffected() > 0)
+        {
+            query.first();
+            ID = query.value(0).toInt();
+            matchType = (query.value(1).toString() == "All") ? " AND " : " OR ";
+            orderBy = QString::fromUtf8(query.value(2).toString());
+            limitTo = query.value(3).toInt();
+        }
+        else
+        {
+            cout << "Cannot find smartplaylist: " << name << endl;
+            return;
+        }
+    }
+    else
+    {
+        MythContext::DBError("Find SmartPlaylist", query);
+        return;   
+    }
+    
+    // get smartplaylist items
+    QString whereClause = "WHERE ";
+    
+    query.prepare("SELECT field, operator, value1, value2 "
+                  "FROM smartplaylistitem WHERE smartplaylistid = :ID;");
+    query.bindValue(":ID", ID);
+    query.exec();
+    if (query.isActive() && query.numRowsAffected() > 0)
+    {
+        bool bFirst = true;
+        while (query.next())
+        {
+            QString fieldName = QString::fromUtf8(query.value(0).toString());
+            QString operatorName = QString::fromUtf8(query.value(1).toString());
+            QString value1 = QString::fromUtf8(query.value(2).toString());
+            QString value2 = QString::fromUtf8(query.value(3).toString());
+            if (!bFirst)
+                whereClause += matchType + getCriteriaSQL(fieldName, operatorName, value1, value2); 
+            else
+            {
+               bFirst = false;
+               whereClause += " " + getCriteriaSQL(fieldName, operatorName, value1, value2);
+            }
+        }
+    }
+    
+    // add order by clause
+    whereClause += getOrderBySQL(orderBy);
+    
+    // add limit
+    if (limitTo > 0)
+        whereClause +=  " LIMIT " + QString::number(limitTo); 
+             
+    fillSonglistFromQuery(whereClause); 
+}
+    
 void Playlist::savePlaylist(QString a_name, QSqlDatabase *a_db)
 {
     if (!a_db)
@@ -571,24 +697,28 @@ void Playlist::savePlaylist(QString a_name, QSqlDatabase *a_db)
         return;
 
     fillSonglistFromSongs();
-    
-    QString thequery  = QString("SELECT NULL FROM musicplaylist WHERE playlistid = %1 ;").arg(playlistid);
 
-    QSqlQuery query = a_db->exec(thequery);
+    MSqlQuery query(QString::null, a_db);        
+    query.prepare("SELECT NULL FROM musicplaylist WHERE playlistid = :ID ;");
+    query.bindValue(":ID", playlistid);
 
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.size() > 0)
     {
-        thequery = QString("UPDATE musicplaylist SET songlist = \"%1\", name = \"%2\" WHERE "
-                           "playlistid = \"%3\" ;")
-                           .arg(raw_songlist).arg(a_name).arg(playlistid);
+        query.prepare("UPDATE musicplaylist SET songlist = :LIST , "
+                      "name = :NAME WHERE playlistid = :ID ;");
+        query.bindValue(":LIST", raw_songlist);
+        query.bindValue(":NAME", a_name.utf8());
+        query.bindValue(":ID", playlistid);
     }
     else
     {
-        thequery = QString("INSERT musicplaylist (name,songlist) "
-                           "VALUES(\"%2\",\"%1\");")
-                           .arg(raw_songlist).arg(a_name);
+        query.prepare("INSERT INTO musicplaylist (name,songlist) "
+                      "VALUES(:NAME, :LIST);");
+        query.bindValue(":LIST", raw_songlist);
+        query.bindValue(":NAME", a_name.utf8());
     }
-    query = a_db->exec(thequery);
+
+    query.exec();
 }
 
 void Playlist::saveNewPlaylist(QSqlDatabase *a_db, QString a_host)
@@ -613,15 +743,20 @@ void Playlist::saveNewPlaylist(QSqlDatabase *a_db, QString a_host)
 
     fillSonglistFromSongs();
     
+    MSqlQuery query(QString::null, a_db);
+    query.prepare("INSERT musicplaylist (name, hostname) "
+                  "VALUES(:NAME, :HOST);");
+    query.bindValue(":NAME", name.utf8());
+    query.bindValue(":HOST", a_host);
 
-    QString thequery  = QString("INSERT INTO musicplaylist (name, hostname) VALUES (\"%1\", \"%2\") ;").arg(name).arg(a_host);
+    query.exec();
 
-    QSqlQuery query = a_db->exec(thequery);
+    query.prepare("SELECT playlistid FROM musicplaylist WHERE "
+                  "name = :NAME AND hostname = :HOST ;");
+    query.bindValue(":NAME", name.utf8());
+    query.bindValue(":HOST", a_host);
 
-    thequery = QString("SELECT playlistid FROM musicplaylist WHERE name = \"%1\" AND hostname = \"%2\" ;").arg(name).arg(a_host);
-
-    query = a_db->exec(thequery);
-    if (query.isActive() && query.numRowsAffected() > 0)
+    if (query.exec() && query.isActive() && query.size() > 0)
     {
         while(query.next())
         {
@@ -632,7 +767,7 @@ void Playlist::saveNewPlaylist(QSqlDatabase *a_db, QString a_host)
     }
     else
     {
-        cerr << "playlist.o: This is not good. Couldn't get an id back on something I just inserted" << endl ;
+        MythContext::DBError("playlist insert", query);
     }
 }
 
@@ -696,7 +831,7 @@ int Playlist::writeTree(GenericTree *tree_to_write_to, int a_counter)
                 Metadata *tmpdata = all_available_music->getMetadata(it->getValue());
                 if (tmpdata)
                 {
-                    QString a_string = QString(QObject::tr("%1 ~ %2")).arg(tmpdata->Artist()).arg(tmpdata->Title());
+                    QString a_string = QString(QObject::tr("%1 ~ %2")).arg(tmpdata->FormatArtist()).arg(tmpdata->FormatTitle());
                     GenericTree *added_node = tree_to_write_to->addNode(a_string, it->getValue(), true);
                     ++a_counter;
                     added_node->setAttribute(0, 1);
@@ -739,16 +874,18 @@ int Playlist::writeTree(GenericTree *tree_to_write_to, int a_counter)
             //  f'ing CD tracks to keep Isaac happy
             //
 
-            Metadata *tmpdata = all_available_music->getMetadata(it->getValue() * -1);
+            Metadata *tmpdata = all_available_music->getMetadata(it->getValue());
             if (tmpdata)
             {
-                QString a_string = QString(QObject::tr("%1 ~ %2")).arg(tmpdata->Artist()).arg(tmpdata->Title());
-                if(tmpdata->Artist().length() < 1 ||
-                   tmpdata-> Title().length() < 1)
+                QString a_string = QString(QObject::tr("CD: %1 ~ %2 - %3"))
+                  .arg(tmpdata->FormatArtist()).arg(tmpdata->Track()).arg(tmpdata->FormatTitle());
+
+                if(tmpdata->FormatArtist().length() < 1 ||
+                   tmpdata->FormatTitle().length() < 1)
                 {
                     a_string = QString("CD Track %1").arg(tmpdata->Track());
                 }
-                GenericTree *added_node = tree_to_write_to->addNode(a_string, it->getValue() * -1, true);
+                GenericTree *added_node = tree_to_write_to->addNode(a_string, it->getValue(), true);
                 ++a_counter;
                 added_node->setAttribute(0, 1);
                 added_node->setAttribute(1, a_counter); //  regular order
@@ -969,11 +1106,13 @@ void PlaylistsContainer::deletePlaylist(int kill_me)
         }
     }
 
-    QString aquery = QString("DELETE FROM musicplaylist WHERE playlistid = %1 ;").arg(kill_me);
-    QSqlQuery query = db->exec(aquery);
-    if(query.numRowsAffected() < 1)
+    MSqlQuery query(QString::null, db);
+    query.prepare("DELETE FROM musicplaylist WHERE playlistid = :ID ;");
+    query.bindValue(":ID", kill_me);
+
+    if (query.exec() || query.size() < 1)
     {
-        cerr << "playlist.o: Hmmm, that's odd ... I tried to delete a playlist but the database couldn't find it" << endl ;
+        MythContext::DBError("playlist delete", query);
     }
     list_to_kill->removeAllTracks();
     all_other_playlists->remove(list_to_kill);
@@ -992,7 +1131,7 @@ QString PlaylistsContainer::getPlaylistName(int index, bool &reference)
         Playlist *a_list;
         for(a_list = all_other_playlists->last(); a_list; a_list = all_other_playlists->prev())
         {
-            if(a_list->getID() == index)
+            if (a_list->getID() * -1 == index)
             {
                 return a_list->getName();   
             }
@@ -1019,7 +1158,7 @@ bool Playlist::containsReference(int to_check, int depth)
     for(it = songs.first(); it; it = songs.next())
     {
         check = it->getValue();
-        if(check < 0)
+        if (check < 0 && !it->getCDFlag())
         {
             if(check * -1 == to_check)
             {
