@@ -10,7 +10,7 @@ class Metadata;
 class VorbisDecoder : public Decoder
 {
   public:
-    VorbisDecoder(const QString &file, DecoderFactory *, QIODevice *, Output *);
+    VorbisDecoder(const QString &file, DecoderFactory *, QIODevice *, AudioOutput *);
     virtual ~VorbisDecoder(void);
 
     bool initialize();
@@ -40,8 +40,6 @@ class VorbisDecoder : public Decoder
     int chan;
     unsigned long output_size;
     double totalTime, seekTime;
-
-    QString getComment(vorbis_comment *comment, const char *label);
 };
 
 #endif
